@@ -41,11 +41,11 @@ class FieldAnalysisIcepak(Analysis, object):
     NG : bool, optional
         Whether to run AEDT in the non-graphical mode. The default
         is ``False``, in which case AEDT launches in the graphical mode.
-    AlwaysNew : bool, optional
+    new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
         machine. The default is ``True``.
-    release_on_exit : bool, optional
+    close_on_exit : bool, optional
         Whether to release  AEDT on exit. The default is ``False``.
     student_version : bool, optional
         Whether to enable the student version of AEDT. The default
@@ -53,10 +53,32 @@ class FieldAnalysisIcepak(Analysis, object):
 
     """
 
-    def __init__(self, application, projectname, designname, solutiontype, setup_name=None,
-                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
-        Analysis.__init__(self, application, projectname, designname, solutiontype, setup_name,
-                          specified_version, NG, AlwaysNew, release_on_exit, student_version)
+    def __init__(
+        self,
+        application,
+        projectname,
+        designname,
+        solutiontype,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=False,
+        close_on_exit=False,
+        student_version=False,
+    ):
+        Analysis.__init__(
+            self,
+            application,
+            projectname,
+            designname,
+            solutiontype,
+            setup_name,
+            specified_version,
+            non_graphical,
+            new_desktop_session,
+            close_on_exit,
+            student_version,
+        )
         self._modeler = Modeler3D(self)
         self._mesh = IcepakMesh(self)
 
@@ -85,8 +107,15 @@ class FieldAnalysisIcepak(Analysis, object):
     #     return self._post
 
     @aedt_exception_handler
-    def apply_icepak_settings(self, ambienttemp=20, gravityDir=5, perform_minimal_val=True, default_fluid="air",
-                              default_solid="Al-Extruded", default_surface="Steel-oxidised-surface"):
+    def apply_icepak_settings(
+        self,
+        ambienttemp=20,
+        gravityDir=5,
+        perform_minimal_val=True,
+        default_fluid="air",
+        default_solid="Al-Extruded",
+        default_surface="Steel-oxidised-surface",
+    ):
         """Apply Icepak default design settings.
 
         Parameters
@@ -113,7 +142,7 @@ class FieldAnalysisIcepak(Analysis, object):
 
         """
         if type(ambienttemp) is int:
-            AmbientTemp = str(ambienttemp)+"cel"
+            AmbientTemp = str(ambienttemp) + "cel"
         else:
             AmbientTemp = ambienttemp
 
@@ -123,12 +152,31 @@ class FieldAnalysisIcepak(Analysis, object):
             GVPos = True
         GVA = IceGravity[int(gravityDir) - 3]
         self.odesign.SetDesignSettings(
-            ["NAME:Design Settings Data", "Perform Minimal validation:=", perform_minimal_val, "Default Fluid Material:=",
-             default_fluid, "Default Solid Material:=", default_solid, "Default Surface Material:=", default_surface,
-             "AmbientTemperature:=", AmbientTemp, "AmbientPressure:=", "0n_per_meter_sq",
-             "AmbientRadiationTemperature:=", AmbientTemp,
-             "Gravity Vector CS ID:=", 1, "Gravity Vector Axis:=", GVA, "Positive:=", GVPos],
-            ["NAME:Model Validation Settings"])
+            [
+                "NAME:Design Settings Data",
+                "Perform Minimal validation:=",
+                perform_minimal_val,
+                "Default Fluid Material:=",
+                default_fluid,
+                "Default Solid Material:=",
+                default_solid,
+                "Default Surface Material:=",
+                default_surface,
+                "AmbientTemperature:=",
+                AmbientTemp,
+                "AmbientPressure:=",
+                "0n_per_meter_sq",
+                "AmbientRadiationTemperature:=",
+                AmbientTemp,
+                "Gravity Vector CS ID:=",
+                1,
+                "Gravity Vector Axis:=",
+                GVA,
+                "Positive:=",
+                GVPos,
+            ],
+            ["NAME:Model Validation Settings"],
+        )
         return True
 
     @aedt_exception_handler
@@ -161,8 +209,12 @@ class FieldAnalysisIcepak(Analysis, object):
         excitation = {"HFSS": "HfssTab", "Icepak": "Icepak", "Q3D": "Q3D", "Maxwell3D": "Maxwell3D"}
         setup = {"HFSS": "HfssTab", "Icepak": "Icepak", "Q3D": "General", "Maxwell3D": "General"}
         mesh = {"HFSS": "MeshSetupTab", "Icepak": "Icepak", "Q3D": "Q3D", "Maxwell3D": "Maxwell3D"}
-        all = {"HFSS": ["HfssTab", "MeshSetupTab"], "Icepak": ["Icepak"],
-            "Q3D": ["Q3D", "General"], "Maxwell3D" : ["Maxwell3D", "General"]}
+        all = {
+            "HFSS": ["HfssTab", "MeshSetupTab"],
+            "Icepak": ["Icepak"],
+            "Q3D": ["Q3D", "General"],
+            "Maxwell3D": ["Maxwell3D", "General"],
+        }
         if type == "Boundary":
             propserv = boundary[self._design_type]
             val = self.odesign.GetPropertyValue(propserv, objectname, property)
@@ -223,13 +275,13 @@ class FieldAnalysisIcepak(Analysis, object):
                     include_object = False
             for key, val in material_properties.items():
                 if val.name == body:
-                    if no_vacuum and val.material_name == 'Vacuum':
+                    if no_vacuum and val.material_name == "Vacuum":
                         include_object = False
-                    if no_pec and val.material_name == 'pec':
+                    if no_pec and val.material_name == "pec":
                         include_object = False
             if include_object:
                 selection_list.append(body)
-        design.modeler.oeditor.Copy(["NAME:Selections", "Selections:=", ','.join(selection_list)])
+        design.modeler.oeditor.Copy(["NAME:Selections", "Selections:=", ",".join(selection_list)])
         self.modeler.oeditor.Paste()
         return True
 
@@ -242,8 +294,7 @@ class FieldAnalysisIcepak(Analysis, object):
 
         """
         # raise a DeprecationWarning.  User won't have to change anything
-        warnings.warn('assignmaterial is deprecated. Use assign_material instead.',
-                      DeprecationWarning)
+        warnings.warn("assignmaterial is deprecated. Use assign_material instead.", DeprecationWarning)
         self.assign_material(obj, mat)
 
     @aedt_exception_handler
@@ -278,7 +329,7 @@ class FieldAnalysisIcepak(Analysis, object):
             else:
                 arg2.append("SolveInside:="), arg2.append(False)
             self.modeler.oeditor.AssignMaterial(arg1, arg2)
-            self._messenger.add_info_message('Assign Material ' + mat + ' to object ' + selections)
+            self._messenger.add_info_message("Assign Material " + mat + " to object " + selections)
             self.materials._aedmattolibrary(mat)
             for el in obj:
                 self.modeler.primitives[el].material_name = mat
@@ -290,7 +341,7 @@ class FieldAnalysisIcepak(Analysis, object):
             else:
                 arg2.append("SolveInside:="), arg2.append(False)
             self.modeler.oeditor.AssignMaterial(arg1, arg2)
-            self._messenger.add_info_message('Assign Material ' + mat + ' to object ' + selections)
+            self._messenger.add_info_message("Assign Material " + mat + " to object " + selections)
             for el in obj:
                 self.modeler.primitives[el].material_name = mat
             return True
@@ -299,7 +350,7 @@ class FieldAnalysisIcepak(Analysis, object):
             return False
 
     @aedt_exception_handler
-    def _assign_property_to_mat(self,newmat, val, property):
+    def _assign_property_to_mat(self, newmat, val, property):
         """Assign a property to a new material.
 
         Parameters
@@ -325,12 +376,16 @@ class FieldAnalysisIcepak(Analysis, object):
             else:
                 value_splitted = val.split(",")
                 value_list = [
-                    [float(re.findall("[-+]?[.]?[\d]+(?:,\d\d\d)*[\.]?\d*(?:[eE][-+]?\d+)?", a)[0]) for a in
-                     d.split("@")] for d in value_splitted]
+                    [
+                        float(re.findall("[-+]?[.]?[\d]+(?:,\d\d\d)*[\.]?\d*(?:[eE][-+]?\d+)?", a)[0])
+                        for a in d.split("@")
+                    ]
+                    for d in value_splitted
+                ]
                 val0 = float(value_list[0][0])
                 for el in value_list:
                     el.reverse()
-                    el[1] = float(el[1])/val0
+                    el[1] = float(el[1]) / val0
                 newmat.set_property_value(property, val0)
                 dataset = newmat.create_thermal_modifier(value_list)
                 newmat.set_property_therm_modifier(property, dataset)
@@ -339,16 +394,17 @@ class FieldAnalysisIcepak(Analysis, object):
             return False
 
     @aedt_exception_handler
-    def _create_dataset_from_sherlock(self, material_name, material_string, property_name= "Mass_Density"):
+    def _create_dataset_from_sherlock(self, material_name, material_string, property_name="Mass_Density"):
         mats = material_string.split(",")
         mat_temp = [[i.split("@")[0], i.split("@")[1]] for i in mats]
         nominal_id = int(len(mat_temp) / 2)
-        nominal_val = float(mat_temp[nominal_id-1][0])
-        ds_name= generate_unique_name(property_name)
-        self.create_dataset(ds_name,
-                            [float(i[1].replace("C", "").replace("K", "").replace("F", ""))
-                                   for i in mat_temp],
-                            [float(i[0]) / nominal_val for i in mat_temp])
+        nominal_val = float(mat_temp[nominal_id - 1][0])
+        ds_name = generate_unique_name(property_name)
+        self.create_dataset(
+            ds_name,
+            [float(i[1].replace("C", "").replace("K", "").replace("F", "")) for i in mat_temp],
+            [float(i[0]) / nominal_val for i in mat_temp],
+        )
         return nominal_val, "$" + ds_name
 
     @aedt_exception_handler
@@ -390,10 +446,10 @@ class FieldAnalysisIcepak(Analysis, object):
         all_objs = self.modeler.primitives.object_names
         i = 0
         for mat in material_data["Name"]:
-            list_mat_obj = ["COMP_" + rd for rd, md in zip(component_data["Ref Des"], component_data["Material"]) if
-                            md == mat]
-            list_mat_obj += [rd for rd, md in zip(component_data["Ref Des"], component_data["Material"]) if
-                            md == mat]
+            list_mat_obj = [
+                "COMP_" + rd for rd, md in zip(component_data["Ref Des"], component_data["Material"]) if md == mat
+            ]
+            list_mat_obj += [rd for rd, md in zip(component_data["Ref Des"], component_data["Material"]) if md == mat]
             list_mat_obj = [mo for mo in list_mat_obj if mo in all_objs]
             if list_mat_obj:
                 if not self.materials.checkifmaterialexists(mat.lower()):
@@ -401,47 +457,53 @@ class FieldAnalysisIcepak(Analysis, object):
                 else:
                     newmat = self.materials[mat.lower()]
                 if "Material Density" in material_data:
-                    if "@" in material_data["Material Density"][i] and "," in  material_data["Material Density"][i]:
-                        nominal_val, dataset_name = self._create_dataset_from_sherlock(mat, material_data[
-                            "Material Density"][i], "Mass_Density")
+                    if "@" in material_data["Material Density"][i] and "," in material_data["Material Density"][i]:
+                        nominal_val, dataset_name = self._create_dataset_from_sherlock(
+                            mat, material_data["Material Density"][i], "Mass_Density"
+                        )
                         newmat.mass_density = nominal_val
                         newmat.mass_density.thermalmodifier = "pwl({}, Temp)".format(dataset_name)
                     else:
                         value = material_data["Material Density"][i]
                         newmat.mass_density = value
                 if "Thermal Conductivity" in material_data:
-                    if "@" in material_data["Thermal Conductivity"][i] and "," in  material_data["Thermal Conductivity"][i]:
-                        nominal_val, dataset_name = self._create_dataset_from_sherlock(mat, material_data[
-                            "Thermal Conductivity"][i], "Thermal_Conductivity")
+                    if (
+                        "@" in material_data["Thermal Conductivity"][i]
+                        and "," in material_data["Thermal Conductivity"][i]
+                    ):
+                        nominal_val, dataset_name = self._create_dataset_from_sherlock(
+                            mat, material_data["Thermal Conductivity"][i], "Thermal_Conductivity"
+                        )
                         newmat.thermal_conductivity = nominal_val
-                        newmat.thermal_conductivity.thermalmodifier = "pwl({}, Temp)".format(
-                            dataset_name)
+                        newmat.thermal_conductivity.thermalmodifier = "pwl({}, Temp)".format(dataset_name)
                     else:
                         value = material_data["Thermal Conductivity"][i]
                         newmat.thermal_conductivity = value
                 if "Material CTE" in material_data:
-                    if "@" in material_data["Material CTE"][i] and "," in  material_data["Material CTE"][i]:
-                        nominal_val, dataset_name = self._create_dataset_from_sherlock(mat, material_data[
-                            "Material CTE"][i], "CTE")
+                    if "@" in material_data["Material CTE"][i] and "," in material_data["Material CTE"][i]:
+                        nominal_val, dataset_name = self._create_dataset_from_sherlock(
+                            mat, material_data["Material CTE"][i], "CTE"
+                        )
                         newmat.thermal_expansion_coefficient = nominal_val
-                        newmat.thermal_expansion_coefficient.thermalmodifier = "pwl({}, Temp)".format(
-                            dataset_name)
+                        newmat.thermal_expansion_coefficient.thermalmodifier = "pwl({}, Temp)".format(dataset_name)
                     else:
                         value = material_data["Material CTE"][i]
                         newmat.thermal_expansion_coefficient = value
                 if "Poisson Ratio" in material_data:
-                    if "@" in material_data["Poisson Ratio"][i] and "," in  material_data["Poisson Ratio"][i]:
-                        nominal_val, dataset_name = self._create_dataset_from_sherlock(mat, material_data[
-                            "Poisson Ratio"][i], "Poisson_Ratio")
+                    if "@" in material_data["Poisson Ratio"][i] and "," in material_data["Poisson Ratio"][i]:
+                        nominal_val, dataset_name = self._create_dataset_from_sherlock(
+                            mat, material_data["Poisson Ratio"][i], "Poisson_Ratio"
+                        )
                         newmat.poissons_ratio = nominal_val
                         newmat.poissons_ratio.thermalmodifier = "pwl({}, Temp)".format(dataset_name)
                     else:
                         value = material_data["Poisson Ratio"][i]
                         newmat.poissons_ratio = value
                 if "Elastic Modulus" in material_data:
-                    if "@" in material_data["Elastic Modulus"][i] and "," in  material_data["Elastic Modulus"][i]:
-                        nominal_val, dataset_name = self._create_dataset_from_sherlock(mat, material_data[
-                            "Elastic Modulus"][i], "Youngs_Modulus")
+                    if "@" in material_data["Elastic Modulus"][i] and "," in material_data["Elastic Modulus"][i]:
+                        nominal_val, dataset_name = self._create_dataset_from_sherlock(
+                            mat, material_data["Elastic Modulus"][i], "Youngs_Modulus"
+                        )
                         newmat.youngs_modulus = nominal_val
                         newmat.youngs_modulus.thermalmodifier = "pwl({}, Temp)".format(dataset_name)
                     else:
