@@ -3,19 +3,18 @@ This module contains these clases: `CircuitPort`, `CurrentSource`, `EdbSiwave`,
 `PinGroup`, `ResistorSource`, `Source`, `SourceType`, and `VoltageSource`.
 """
 
-import warnings
 import os
 import time
-from .general import *
-from ..generic.general_methods import get_filename_without_extension, generate_unique_name, retry_ntimes
+import warnings
+
 from pyaedt import is_ironpython
+from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, retry_ntimes
+
 try:
-    import clr
-    from System import Convert, String
-    from System import Double, Array
-    from System.Collections.Generic import List, Dictionary
+    from System import String
+    from System.Collections.Generic import Dictionary
 except ImportError:
-    warnings.warn('This module requires pythonnet.')
+    warnings.warn("This module requires pythonnet.")
 
 
 class SiwaveDCSetupTemplate(object):
@@ -113,6 +112,7 @@ class SiwaveDCSetupTemplate(object):
 
 class SourceType(object):
     """Manages source types."""
+
     (Port, CurrentSource, VoltageSource, Resistor) = (1, 2, 3, 4)
 
 
@@ -178,7 +178,7 @@ class Source(object):
         return self._name
 
     @name.setter
-    def name(self,value):
+    def name(self, value):
         self._name = value
 
     @property
@@ -187,7 +187,7 @@ class Source(object):
         return self._type
 
     @type.setter
-    def type(self,value):
+    def type(self, value):
         self.type = value
 
     @property
@@ -196,7 +196,7 @@ class Source(object):
         return self._positive_node
 
     @positive_node.setter
-    def positive_node(self,value):
+    def positive_node(self, value):
         self._positive_node = value
 
     @property
@@ -205,7 +205,7 @@ class Source(object):
         return self._negative_node
 
     @negative_node.setter
-    def negative_node(self,value):
+    def negative_node(self, value):
         self._negative_node = value
 
     @property
@@ -214,7 +214,7 @@ class Source(object):
         return self._do_pin_grouping
 
     @do_pin_grouping.setter
-    def do_pin_grouping(self,value):
+    def do_pin_grouping(self, value):
         self._do_pin_grouping = value
 
 
@@ -232,7 +232,7 @@ class CircuitPort(Source):
         return self._impedance
 
     @impedance.setter
-    def impedance(self,value):
+    def impedance(self, value):
         self._impedance = value
 
     @property
@@ -254,7 +254,7 @@ class VoltageSource(Source):
     @property
     def magnitude(self):
         """Magnitude."""
-        return  self._magnitude
+        return self._magnitude
 
     @magnitude.setter
     def magnitude(self, value):
@@ -266,7 +266,7 @@ class VoltageSource(Source):
         return self._phase
 
     @phase.setter
-    def phase(self,value):
+    def phase(self, value):
         self._phase = value
 
     @property
@@ -275,7 +275,7 @@ class VoltageSource(Source):
         return self._impedance
 
     @impedance.setter
-    def impedance(self,value):
+    def impedance(self, value):
         self._impedance = value
 
     @property
@@ -297,7 +297,7 @@ class CurrentSource(Source):
     @property
     def magnitude(self):
         """Magnitude."""
-        return  self._magnitude
+        return self._magnitude
 
     @magnitude.setter
     def magnitude(self, value):
@@ -309,7 +309,7 @@ class CurrentSource(Source):
         return self._phase
 
     @phase.setter
-    def phase(self,value):
+    def phase(self, value):
         self._phase = value
 
     @property
@@ -318,7 +318,7 @@ class CurrentSource(Source):
         return self._impedance
 
     @impedance.setter
-    def impedance(self,value):
+    def impedance(self, value):
         self._impedance = value
 
     @property
@@ -338,7 +338,7 @@ class ResistorSource(Source):
     @property
     def rvalue(self):
         """Resistance value."""
-        return  self._rvalue
+        return self._rvalue
 
     @rvalue.setter
     def rvalue(self, value):
@@ -428,11 +428,25 @@ class EdbSiwave(object):
         else:
             res, fromLayer_pos, toLayer_pos = source.positive_node.node_pins.GetLayerRange(None, None)
             res, fromLayer_neg, toLayer_neg = source.negative_node.node_pins.GetLayerRange(None, None)
-        pos_pingroup_terminal = retry_ntimes(10,self._edb.Cell.Terminal.PadstackInstanceTerminal.Create,self._active_layout, pos_pin.GetNet(),
-                                                                           pos_pin.GetName(), pos_pin, toLayer_pos)
+        pos_pingroup_terminal = retry_ntimes(
+            10,
+            self._edb.Cell.Terminal.PadstackInstanceTerminal.Create,
+            self._active_layout,
+            pos_pin.GetNet(),
+            pos_pin.GetName(),
+            pos_pin,
+            toLayer_pos,
+        )
         time.sleep(0.5)
-        neg_pingroup_terminal = retry_ntimes(10,self._edb.Cell.Terminal.PadstackInstanceTerminal.Create,self._active_layout, neg_pin.GetNet(),
-                                                                           neg_pin.GetName(), neg_pin, toLayer_neg)
+        neg_pingroup_terminal = retry_ntimes(
+            10,
+            self._edb.Cell.Terminal.PadstackInstanceTerminal.Create,
+            self._active_layout,
+            neg_pin.GetNet(),
+            neg_pin.GetName(),
+            neg_pin,
+            toLayer_neg,
+        )
         if source.type == SourceType.Port:
             pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
             neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
@@ -525,17 +539,21 @@ class EdbSiwave(object):
         circuit_port.impedance = impedance
 
         if not port_name:
-            port_name = "Port_{}_{}_{}_{}".format(pos_pin.GetComponent().GetName(), pos_pin.GetNet().GetName(),
-                                                  neg_pin.GetComponent().GetName(), neg_pin.GetNet().GetName())
+            port_name = "Port_{}_{}_{}_{}".format(
+                pos_pin.GetComponent().GetName(),
+                pos_pin.GetNet().GetName(),
+                neg_pin.GetComponent().GetName(),
+                neg_pin.GetNet().GetName(),
+            )
         circuit_port.name = port_name
         circuit_port.positive_node.component_node = pos_pin.GetComponent()
         circuit_port.positive_node.node_pins = pos_pin
         circuit_port.negative_node.component_node = neg_pin.GetComponent()
         circuit_port.negative_node.node_pins = neg_pin
-        return  self._create_terminal_on_pins(circuit_port)
+        return self._create_terminal_on_pins(circuit_port)
 
     @aedt_exception_handler
-    def create_voltage_source_on_pin(self, pos_pin, neg_pin, voltage_value=3.3, phase_value=0,source_name=""):
+    def create_voltage_source_on_pin(self, pos_pin, neg_pin, voltage_value=3.3, phase_value=0, source_name=""):
         """Create a voltage source.
 
         Parameters
@@ -571,8 +589,12 @@ class EdbSiwave(object):
         voltage_source.magnitude = voltage_value
         voltage_source.phase = phase_value
         if not source_name:
-            source_name = "VSource_{}_{}_{}_{}".format(pos_pin.GetComponent().GetName(), pos_pin.GetNet().GetName(),
-                                                       neg_pin.GetComponent().GetName(), neg_pin.GetNet().GetName())
+            source_name = "VSource_{}_{}_{}_{}".format(
+                pos_pin.GetComponent().GetName(),
+                pos_pin.GetNet().GetName(),
+                neg_pin.GetComponent().GetName(),
+                neg_pin.GetNet().GetName(),
+            )
         voltage_source.name = source_name
         voltage_source.positive_node.component_node = pos_pin.GetComponent()
         voltage_source.positive_node.node_pins = pos_pin
@@ -616,8 +638,12 @@ class EdbSiwave(object):
         current_source.magnitude = current_value
         current_source.phase = phase_value
         if not source_name:
-            source_name = "ISource_{}_{}_{}_{}".format(pos_pin.GetComponent().GetName(), pos_pin.GetNet().GetName(),
-                                                       neg_pin.GetComponent().GetName(), neg_pin.GetNet().GetName())
+            source_name = "ISource_{}_{}_{}_{}".format(
+                pos_pin.GetComponent().GetName(),
+                pos_pin.GetNet().GetName(),
+                neg_pin.GetComponent().GetName(),
+                neg_pin.GetNet().GetName(),
+            )
         current_source.name = source_name
         current_source.positive_node.component_node = pos_pin.GetComponent()
         current_source.positive_node.node_pins = pos_pin
@@ -658,8 +684,12 @@ class EdbSiwave(object):
         resistor.negative_node.net = neg_pin.GetNet().GetName()
         resistor.magnitude = rvalue
         if not resistor_name:
-            resistor_name = "Res_{}_{}_{}_{}".format(pos_pin.GetComponent().GetName(), pos_pin.GetNet().GetName(),
-                                                       neg_pin.GetComponent().GetName(), neg_pin.GetNet().GetName())
+            resistor_name = "Res_{}_{}_{}_{}".format(
+                pos_pin.GetComponent().GetName(),
+                pos_pin.GetNet().GetName(),
+                neg_pin.GetComponent().GetName(),
+                neg_pin.GetNet().GetName(),
+            )
         resistor.name = resistor_name
         resistor.positive_node.component_node = pos_pin.GetComponent()
         resistor.positive_node.node_pins = pos_pin
@@ -683,8 +713,15 @@ class EdbSiwave(object):
         return negative_net_name
 
     @aedt_exception_handler
-    def create_circuit_port_on_net(self, positive_component_name, positive_net_name, negative_component_name=None,
-                              negative_net_name=None, impedance_value=50, port_name=""):
+    def create_circuit_port_on_net(
+        self,
+        positive_component_name,
+        positive_net_name,
+        negative_component_name=None,
+        negative_net_name=None,
+        impedance_value=50,
+        port_name="",
+    ):
         """Create a circuit port on a NET.
 
         It groups all pins belonging to the specified net and then applies the port on PinGroups.
@@ -730,7 +767,9 @@ class EdbSiwave(object):
         pos_node_pins = self.parent.core_components.get_pin_from_component(positive_component_name, positive_net_name)
         neg_node_pins = self.parent.core_components.get_pin_from_component(negative_component_name, negative_net_name)
         if port_name == "":
-            port_name = "Port_{}_{}_{}_{}".format(positive_component_name,positive_net_name,negative_component_name,negative_net_name)
+            port_name = "Port_{}_{}_{}_{}".format(
+                positive_component_name, positive_net_name, negative_component_name, negative_net_name
+            )
         circuit_port.name = port_name
         circuit_port.positive_node.component_node = pos_node_cmp
         circuit_port.positive_node.node_pins = pos_node_pins
@@ -739,8 +778,16 @@ class EdbSiwave(object):
         return self.create_pin_group_terminal(circuit_port)
 
     @aedt_exception_handler
-    def create_voltage_source_on_net(self, positive_component_name, positive_net_name, negative_component_name=None,
-                              negative_net_name=None, voltage_value=3.3, phase_value=0,source_name=""):
+    def create_voltage_source_on_net(
+        self,
+        positive_component_name,
+        positive_net_name,
+        negative_component_name=None,
+        negative_net_name=None,
+        voltage_value=3.3,
+        phase_value=0,
+        source_name="",
+    ):
         """Create a voltage source.
 
         Parameters
@@ -788,8 +835,9 @@ class EdbSiwave(object):
         neg_node_pins = self.parent.core_components.get_pin_from_component(negative_component_name, negative_net_name)
 
         if source_name == "":
-            source_name = "Vsource_{}_{}_{}_{}".format(positive_component_name, positive_net_name, negative_component_name,
-                                                  negative_net_name)
+            source_name = "Vsource_{}_{}_{}_{}".format(
+                positive_component_name, positive_net_name, negative_component_name, negative_net_name
+            )
         voltage_source.name = source_name
         voltage_source.positive_node.component_node = pos_node_cmp
         voltage_source.positive_node.node_pins = pos_node_pins
@@ -798,8 +846,16 @@ class EdbSiwave(object):
         return self.create_pin_group_terminal(voltage_source)
 
     @aedt_exception_handler
-    def create_current_source_on_net(self, positive_component_name, positive_net_name, negative_component_name=None,
-                              negative_net_name=None, current_value=0.1, phase_value=0, source_name=""):
+    def create_current_source_on_net(
+        self,
+        positive_component_name,
+        positive_net_name,
+        negative_component_name=None,
+        negative_net_name=None,
+        current_value=0.1,
+        phase_value=0,
+        source_name="",
+    ):
         """Create a current source.
 
         Parameters
@@ -847,8 +903,9 @@ class EdbSiwave(object):
         neg_node_pins = self.parent.core_components.get_pin_from_component(negative_component_name, negative_net_name)
 
         if source_name == "":
-            source_name = "Port_{}_{}_{}_{}".format(positive_component_name, positive_net_name, negative_component_name,
-                                                    negative_net_name)
+            source_name = "Port_{}_{}_{}_{}".format(
+                positive_component_name, positive_net_name, negative_component_name, negative_net_name
+            )
         current_source.name = source_name
         current_source.positive_node.component_node = pos_node_cmp
         current_source.positive_node.node_pins = pos_node_pins
@@ -857,8 +914,15 @@ class EdbSiwave(object):
         return self.create_pin_group_terminal(current_source)
 
     @aedt_exception_handler
-    def create_resistor_on_net(self, positive_component_name, positive_net_name, negative_component_name=None,
-                              negative_net_name=None, rvalue=1, resistor_name=""):
+    def create_resistor_on_net(
+        self,
+        positive_component_name,
+        positive_net_name,
+        negative_component_name=None,
+        negative_net_name=None,
+        rvalue=1,
+        resistor_name="",
+    ):
         """Create a voltage source.
 
         Parameters
@@ -902,8 +966,9 @@ class EdbSiwave(object):
         neg_node_pins = self.parent.core_components.get_pin_from_component(negative_component_name, negative_net_name)
 
         if resistor_name == "":
-            resistor_name = "Port_{}_{}_{}_{}".format(positive_component_name, positive_net_name, negative_component_name,
-                                                    negative_net_name)
+            resistor_name = "Port_{}_{}_{}_{}".format(
+                positive_component_name, positive_net_name, negative_component_name, negative_net_name
+            )
         resistor.name = resistor_name
         resistor.positive_node.component_node = pos_node_cmp
         resistor.positive_node.node_pins = pos_node_pins
@@ -915,14 +980,23 @@ class EdbSiwave(object):
     def create_exec_file(self):
         """Create an executable file."""
         workdir = os.path.dirname(self.parent.edbpath)
-        file_name = os.path.join(workdir,os.path.splitext(os.path.basename(self.parent.edbpath))[0] + '.exec')
+        file_name = os.path.join(workdir, os.path.splitext(os.path.basename(self.parent.edbpath))[0] + ".exec")
         if os.path.isfile(file_name):
             os.remove(file_name)
-        f = open(file_name,"w")
+        f = open(file_name, "w")
         return f
 
     @aedt_exception_handler
-    def add_siwave_ac_analysis(self, accuracy_level=1, decade_count=10, sweeptype=1, start_freq=1, stop_freq=1e9, step_freq=1e6, discrete_sweep=False):
+    def add_siwave_ac_analysis(
+        self,
+        accuracy_level=1,
+        decade_count=10,
+        sweeptype=1,
+        start_freq=1,
+        stop_freq=1e9,
+        step_freq=1e6,
+        discrete_sweep=False,
+    ):
         """Add a SIwave AC analysis to EDB.
 
         Parameters
@@ -947,15 +1021,32 @@ class EdbSiwave(object):
         bool
             ``True`` when successful, ``False`` when failed.
         """
-        self._siwave_setup.AddACSimSetup(self._builder, accuracy_level, str(decade_count), sweeptype, str(start_freq), str(stop_freq), str(step_freq), discrete_sweep)
+        self._siwave_setup.AddACSimSetup(
+            self._builder,
+            accuracy_level,
+            str(decade_count),
+            sweeptype,
+            str(start_freq),
+            str(stop_freq),
+            str(step_freq),
+            discrete_sweep,
+        )
         exec_file = self.create_exec_file()
         exec_file.write("ExecAcSim\n")
         exec_file.close()
         return True
 
     @aedt_exception_handler
-    def add_siwave_syz_analysis(self, accuracy_level=1, decade_count=10, sweeptype=1, start_freq=1, stop_freq=1e9,
-                               step_freq=1e6, discrete_sweep=False):
+    def add_siwave_syz_analysis(
+        self,
+        accuracy_level=1,
+        decade_count=10,
+        sweeptype=1,
+        start_freq=1,
+        stop_freq=1e9,
+        step_freq=1e6,
+        discrete_sweep=False,
+    ):
         """Add a SIwave SYZ analysis.
 
         Parameters
@@ -981,8 +1072,16 @@ class EdbSiwave(object):
             ``True`` when successful, ``False`` when failed.
         """
 
-        self._siwave_setup.AddSYZSimSetup(self._builder, accuracy_level, str(decade_count), sweeptype, str(start_freq),
-                                        str(stop_freq), str(step_freq), discrete_sweep)
+        self._siwave_setup.AddSYZSimSetup(
+            self._builder,
+            accuracy_level,
+            str(decade_count),
+            sweeptype,
+            str(start_freq),
+            str(stop_freq),
+            str(step_freq),
+            discrete_sweep,
+        )
         exec_file = self.create_exec_file()
         exec_file.write("ExecSyzSim\n")
         exec_file.write("SaveSiw\n")
@@ -1032,9 +1131,13 @@ class EdbSiwave(object):
         >>> edb.core_siwave.add_siwave_dc_analysis2(settings)
 
         """
-        sim_setup_info = self.parent.simsetupdata.SimSetupInfo[self.parent.simsetupdata.SIwave.SIWDCIRSimulationSettings]()
+        sim_setup_info = self.parent.simsetupdata.SimSetupInfo[
+            self.parent.simsetupdata.SIwave.SIWDCIRSimulationSettings
+        ]()
         sim_setup_info.Name = setup_settings.name
-        sim_setup_info.SimulationSettings.DCIRSettings.DCReportShowActiveDevices = setup_settings.dcreport_show_active_devices
+        sim_setup_info.SimulationSettings.DCIRSettings.DCReportShowActiveDevices = (
+            setup_settings.dcreport_show_active_devices
+        )
         sim_setup_info.SimulationSettings.DCIRSettings.ExportDCThermalData = setup_settings.export_dcthermal_data
         sim_setup_info.SimulationSettings.DCIRSettings.FullDCReportPath = setup_settings.full_dcreport_path
         sim_setup_info.SimulationSettings.DCIRSettings.UseLoopResForPerPin = setup_settings.use_loopres_forperpin
@@ -1044,7 +1147,9 @@ class EdbSiwave(object):
         sim_setup_info.SimulationSettings.DCSettings.PlotJV = setup_settings.plotjv
         sim_setup_info.SimulationSettings.DCAdvancedSettings.MinNumPasses = setup_settings.min_passes
         sim_setup_info.SimulationSettings.DCAdvancedSettings.MaxNumPasses = setup_settings.max_passes
-        sim_setup_info.SimulationSettings.DCAdvancedSettings.PercentLocalRefinement = setup_settings.percent_localrefinement
+        sim_setup_info.SimulationSettings.DCAdvancedSettings.PercentLocalRefinement = (
+            setup_settings.percent_localrefinement
+        )
         sim_setup_info.SimulationSettings.DCAdvancedSettings.EnergyError = setup_settings.energy_error
         sim_setup_info.SimulationSettings.DCAdvancedSettings.RefineBws = setup_settings.refine_bondwires
         sim_setup_info.SimulationSettings.DCAdvancedSettings.RefineVias = setup_settings.refine_vias
@@ -1052,7 +1157,9 @@ class EdbSiwave(object):
         sim_setup_info.SimulationSettings.DCAdvancedSettings.NumBwSides = setup_settings.num_bondwire_sides
         sim_setup_info.SimulationSettings.DCAdvancedSettings.MeshBws = setup_settings.mesh_bondwires
         sim_setup_info.SimulationSettings.DCAdvancedSettings.MeshVias = setup_settings.mesh_vias
-        sim_setup_info.SimulationSettings.DCAdvancedSettings.PerformAdaptiveRefinement = setup_settings.perform_adaptive_refinement
+        sim_setup_info.SimulationSettings.DCAdvancedSettings.PerformAdaptiveRefinement = (
+            setup_settings.perform_adaptive_refinement
+        )
         sim_setup_info.SimulationSettings.DCSettings.UseDCCustomSettings = setup_settings.use_dc_custom_settings
         sim_setup_info.SimulationSettings.DCIRSettings.SourceTermsToGround = setup_settings.source_terms_to_ground
         simulationSetup = self._edb.Utility.SIWaveDCIRSimulationSetup(sim_setup_info)
@@ -1084,13 +1191,27 @@ class EdbSiwave(object):
         neg_pin_group = self.parent.core_components.create_pingroup_from_pins(source.negative_node.node_pins)
         pos_node_net = self.parent.core_nets.get_net_by_name(source.positive_node.net)
         neg_node_net = self.parent.core_nets.get_net_by_name(source.negative_node.net)
-        pos_pingroup_term_name = generate_unique_name(source.name + "_POS")
-        neg_pingroup_term_name = generate_unique_name(source.name + "_NEG")
-        pos_pingroup_terminal = retry_ntimes(10, self._edb.Cell.Terminal.PinGroupTerminal.Create, self._active_layout,
-                                             pos_node_net, pos_pingroup_term_name, pos_pin_group[1], False)
+        pos_pingroup_term_name = generate_unique_name(source.name + "_P_", n=3)
+        neg_pingroup_term_name = generate_unique_name(source.name + "_N_", n=3)
+        pos_pingroup_terminal = retry_ntimes(
+            10,
+            self._edb.Cell.Terminal.PinGroupTerminal.Create,
+            self._active_layout,
+            pos_node_net,
+            pos_pingroup_term_name,
+            pos_pin_group[1],
+            False,
+        )
         time.sleep(0.5)
-        neg_pingroup_terminal = retry_ntimes(10, self._edb.Cell.Terminal.PinGroupTerminal.Create, self._active_layout,
-                                             neg_node_net, neg_pingroup_term_name, neg_pin_group[1], False)
+        neg_pingroup_terminal = retry_ntimes(
+            10,
+            self._edb.Cell.Terminal.PinGroupTerminal.Create,
+            self._active_layout,
+            neg_node_net,
+            neg_pingroup_term_name,
+            neg_pin_group[1],
+            False,
+        )
 
         if source.type == SourceType.Port:
             pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
