@@ -41,6 +41,7 @@ def load_keyword_in_aedt_file(filename, keyword):
     """
     return _load_keyword_in_aedt_file(filename, keyword)
 
+
 # --------------------------------------------------------------------
 # internals
 
@@ -48,10 +49,10 @@ def load_keyword_in_aedt_file(filename, keyword):
 # precompile all Regular expressions
 _remove_quotes = re.compile(r"^'(.*?)'$")
 _split_list_elements = re.compile(",(?=(?:[^']*'[^']*')*[^']*$)")
-_round_bracket_list = re.compile(
-    r"^(?P<KEY1>[^\s]+?)\((?P<LIST1>.+)\)|^'(?P<KEY2>.+?\s.+)'(?<=')\((?P<LIST2>.+)\)")
+_round_bracket_list = re.compile(r"^(?P<KEY1>[^\s]+?)\((?P<LIST1>.+)\)|^'(?P<KEY2>.+?\s.+)'(?<=')\((?P<LIST2>.+)\)")
 _square_bracket_list = re.compile(
-    r"^(?P<KEY1>[^\s]+?)\[\d+:(?P<LIST1>.+)\]|^'(?P<KEY2>.+?\s.+)'(?<=')\[\d+:(?P<LIST2>.+)\]")
+    r"^(?P<KEY1>[^\s]+?)\[\d+:(?P<LIST1>.+)\]|^'(?P<KEY2>.+?\s.+)'(?<=')\[\d+:(?P<LIST2>.+)\]"
+)
 _key_parse = re.compile(r"(^'(?P<KEY1>.+?)')(?<=')=(?P<VAL1>.+$)|(?P<KEY2>^.+?)=(?P<VAL2>.+$)")
 _value_parse1 = re.compile(r"\s")
 _value_parse2 = re.compile(r"^'([^']*\s[^']*)(?=')")
@@ -78,9 +79,9 @@ def _parse_value(v):
     #  parse the value 'v'
     if v is None:
         pv = v
-    elif v == 'true':
+    elif v == "true":
         pv = True
-    elif v == 'false':
+    elif v == "false":
         pv = False
     else:
         try:
@@ -109,7 +110,7 @@ def _separate_list_elements(v):
     -------
 
     """
-    if "(" in v or '=' in v:
+    if "(" in v or "=" in v:
         l1 = _split_list_elements.split(v)
     else:
         l1 = v.split(",")
@@ -138,23 +139,23 @@ def _decode_value_and_save(k, v, d):
     # create a list for key[n: 1, 2, ...n]
 
     m = _round_bracket_list.search(k)
-    if m and m.group('KEY1'):
-        v = _separate_list_elements(m.group('LIST1'))
-        k = m.group('KEY1')
+    if m and m.group("KEY1"):
+        v = _separate_list_elements(m.group("LIST1"))
+        k = m.group("KEY1")
         d[k] = v
-    elif m and m.group('KEY2'):
-        v = _separate_list_elements(m.group('LIST2'))
-        k = m.group('KEY2')
+    elif m and m.group("KEY2"):
+        v = _separate_list_elements(m.group("LIST2"))
+        k = m.group("KEY2")
         d[k] = v
     else:
         m = _square_bracket_list.search(k)
-        if m and m.group('KEY1'):
-            v = _separate_list_elements(m.group('LIST1'))
-            k = m.group('KEY1')
+        if m and m.group("KEY1"):
+            v = _separate_list_elements(m.group("LIST1"))
+            k = m.group("KEY1")
             d[k] = v
-        elif m and m.group('KEY2'):
-            v = _separate_list_elements(m.group('LIST2'))
-            k = m.group('KEY2')
+        elif m and m.group("KEY2"):
+            v = _separate_list_elements(m.group("LIST2"))
+            k = m.group("KEY2")
             d[k] = v
         else:
             d[k] = _parse_value(v)
@@ -175,8 +176,8 @@ def _decode_key(l, d):
 
     """
     m = _key_parse.search(l)
-    if m and m.group('KEY1'):  # key btw ''
-        value = m.group('VAL1')
+    if m and m.group("KEY1"):  # key btw ''
+        value = m.group("VAL1")
         if "\\'" in value:
             value2 = value.replace("\\'", '"')
         else:
@@ -184,14 +185,14 @@ def _decode_key(l, d):
         # if there are no spaces in value
         if not _value_parse1.search(value2) or _value_parse2.search(value2):
             # or values with spaces are between quote
-            key = m.group('KEY1')
+            key = m.group("KEY1")
             _decode_value_and_save(key, value, d)
         else:  # spaces in value without quotes
             key = l
             value = None
             _decode_value_and_save(key, value, d)
-    elif m and m.group('KEY2'):  # key without ''
-        value = m.group('VAL2')
+    elif m and m.group("KEY2"):  # key without ''
+        value = m.group("VAL2")
         if "\\'" in value:
             value2 = value.replace("\\'", '"')
         else:
@@ -199,7 +200,7 @@ def _decode_key(l, d):
         # if there are no spaces in value
         if not _value_parse1.search(value2) or _value_parse2.search(value2):
             # or values with spaces are between quote
-            key = m.group('KEY2')
+            key = m.group("KEY2")
             _decode_value_and_save(key, value, d)
         else:  # spaces in value without quotes
             key = l
@@ -226,8 +227,8 @@ def _walk_through_structure(keyword, save_dict):
 
     """
     global _count
-    begin_key = '$begin \'{}\''.format(keyword)
-    end_key = '$end \'{}\''.format(keyword)
+    begin_key = "$begin '{}'".format(keyword)
+    end_key = "$end '{}'".format(keyword)
     found = False
     saved_value = None
     while _count < _len_all_lines:
@@ -235,7 +236,7 @@ def _walk_through_structure(keyword, save_dict):
         # begin_key is found
         if begin_key == line.strip():
             found = True
-            saved_value = save_dict.get(keyword)               # if the keyword is already present
+            saved_value = save_dict.get(keyword)  # if the keyword is already present
             # makes the value a list, if it's not already
             if saved_value and type(saved_value) is not list:
                 saved_value = [saved_value]
@@ -243,7 +244,8 @@ def _walk_through_structure(keyword, save_dict):
             _count += 1
             continue
         # end_key is found
-        if end_key == line.strip(): break
+        if end_key == line.strip():
+            break
         # between begin_key and end_key
         if found:
             b = _begin_search.search(line)
@@ -276,13 +278,13 @@ def _reaf_aedt_file(filename):
     global _len_all_lines
     global _count
     # read the AEDT file and discard the binary part
-    with open(filename, 'rb') as aedt_fh:
+    with open(filename, "rb") as aedt_fh:
         temp = aedt_fh.read().splitlines()
     _all_lines = []
     _count = 0
     for line in temp:
         try:
-            _all_lines.append(line.decode("utf-8").lstrip('\t'))
+            _all_lines.append(line.decode("utf-8").lstrip("\t"))
         except UnicodeDecodeError:
             break
     _len_all_lines = len(_all_lines)
