@@ -1,21 +1,17 @@
-import re
-import os
-from datetime import datetime
 import math
-import cmath
-from .general_methods import generate_unique_name, aedt_exception_handler
-REAL_IMAG = 'RI'
-MAG_ANGLE = 'MA'
-DB_ANGLE = 'DB'
+import os
+import re
 
-keys = {
-    REAL_IMAG: ('real', 'imag'),
-    MAG_ANGLE: ('mag', 'deg'),
-    DB_ANGLE: ('db20', 'deg')
-}
+from .general_methods import aedt_exception_handler
 
-def parameter(real=None, imag=None, mag=None, db10=None, db20=None, deg=None,
-              rad=None):
+REAL_IMAG = "RI"
+MAG_ANGLE = "MA"
+DB_ANGLE = "DB"
+
+keys = {REAL_IMAG: ("real", "imag"), MAG_ANGLE: ("mag", "deg"), DB_ANGLE: ("db20", "deg")}
+
+
+def parameter(real=None, imag=None, mag=None, db10=None, db20=None, deg=None, rad=None):
     """Initialize a parameter
     Specify:
     * real and (optionally) imag, or
@@ -44,21 +40,19 @@ def parameter(real=None, imag=None, mag=None, db10=None, db20=None, deg=None,
     """
     if real is not None:
         if (mag or db10 or db20 or deg or rad) is not None:
-            raise ValueError('Illegal combination of arguments.')
+            raise ValueError("Illegal combination of arguments.")
         if imag is None:
             imag = 0
-    else: # real is None
-        if ((imag is not None) and
-            (mag and db10 and db20 is not None) and
-            (deg and rad is not None)):
-            raise ValueError('Illegal combination of arguments.')
+    else:  # real is None
+        if (imag is not None) and (mag and db10 and db20 is not None) and (deg and rad is not None):
+            raise ValueError("Illegal combination of arguments.")
 
         if db10 is not None:
-            mag = 10**(db10 / 10.0)
+            mag = 10 ** (db10 / 10.0)
         elif db20 is not None:
-            mag = 10**(db20 / 20.0)
+            mag = 10 ** (db20 / 20.0)
         if deg is not None:
-            rad = deg*math.pi/180
+            rad = deg * math.pi / 180
 
         real = mag * math.cos(rad)
         imag = mag * math.sin(rad)
@@ -165,7 +159,7 @@ def rad(arg):
 
 
     """
-    return arg*math.pi/180
+    return arg * math.pi / 180
 
 
 def deg(arg):
@@ -182,14 +176,10 @@ def deg(arg):
 
 
     """
-    return arg*180/math.pi
+    return arg * 180 / math.pi
 
 
-formats = {
-    REAL_IMAG: (real, imag),
-    MAG_ANGLE: (mag, deg),
-    DB_ANGLE: (db20, deg)
-}
+formats = {REAL_IMAG: (real, imag), MAG_ANGLE: (mag, deg), DB_ANGLE: (db20, deg)}
 
 
 class ParseError(Exception):
@@ -207,12 +197,12 @@ class TouchstoneData(object):
 
     def __init__(self, freqs, matrix, portnames):
         self._sweeps_names = ["Freq"]
-        self.sweeps= {"Freq":freqs}
+        self.sweeps = {"Freq": freqs}
         self.ports = portnames
         self.expressions = []
         for el in portnames:
             for el1 in portnames:
-                self.expressions.append("S({},{})".format(el,el1))
+                self.expressions.append("S({},{})".format(el, el1))
 
         self._primary_sweep = "Freq"
         self.solutions_data_real, self.solutions_data_imag = self._solutions_data(matrix)
@@ -220,8 +210,9 @@ class TouchstoneData(object):
         self.units_data = {}
         for expr in self.expressions:
             self.solutions_data_mag[expr] = [
-                abs(complex(self.solutions_data_real[expr][i], self.solutions_data_imag[expr][i])) for i in
-                range(len(self.solutions_data_real[expr]))]
+                abs(complex(self.solutions_data_real[expr][i], self.solutions_data_imag[expr][i]))
+                for i in range(len(self.solutions_data_real[expr]))
+            ]
 
     def _solutions_data(self, matrix):
         """
@@ -237,23 +228,23 @@ class TouchstoneData(object):
         """
         sols_data_real = {}
         sols_data_imag = {}
-        i=0
+        i = 0
         expression = ""
         for element in matrix:
-            k=0
+            k = 0
             for expression in self.expressions:
                 values = []
                 for el in reversed(self._sweeps_names):
                     values.append(self.sweeps[el])
-                t=tuple([self.sweeps["Freq"][i]])
+                t = tuple([self.sweeps["Freq"][i]])
                 if expression in sols_data_real:
                     sols_data_real[expression].append(element[k].real)
                     sols_data_imag[expression].append(element[k].imag)
                 else:
-                    sols_data_real[expression]=[element[k].real]
-                    sols_data_imag[expression]=[element[k].imag]
-                k+=1
-            i+=1
+                    sols_data_real[expression] = [element[k].real]
+                    sols_data_imag[expression] = [element[k].imag]
+                k += 1
+            i += 1
 
         return sols_data_real, sols_data_imag
 
@@ -292,7 +283,7 @@ class TouchstoneData(object):
         if not expression:
             expression = self.expressions[0]
         try:
-            return [10*math.log10(i) for i in self.data_magnitude(expression)]
+            return [10 * math.log10(i) for i in self.data_magnitude(expression)]
         except:
             print("Error in DB Computation")
             return None
@@ -317,7 +308,9 @@ class TouchstoneData(object):
         return list(self.solutions_data_real[expression])
 
     def data_imag(self, expression=None):
-        """Return the imaginary part of data  of the given expression. if no expression is provided, first expression is provided
+        """Return the imaginary part of data  of the given expression.
+
+        If no expression is provided, first expression is provided
 
         Parameters
         ----------
@@ -336,8 +329,10 @@ class TouchstoneData(object):
 
 
 @aedt_exception_handler
-def get_return_losses(excitation_names, excitation_name_prefix=''):
-    """Get the list of all the Returnloss from a list of exctitations. If no excitation is provided it will provide a full list of return Losses
+def get_return_losses(excitation_names, excitation_name_prefix=""):
+    """Get the list of all the Returnloss from a list of exctitations.
+
+    If no excitation is provided it will provide a full list of return Losses
     Example: excitation_names ["1","2"] is_touchstone_expression=False output ["S(1,1)",, S(2,2)]
     Example: excitation_names ["S(1,1)","S(1,2)", S(2,2)] is_touchstone_expression=True output ["S(1,1)",, S(2,2)]
 
@@ -356,12 +351,12 @@ def get_return_losses(excitation_names, excitation_name_prefix=''):
     """
     spar = []
     if excitation_name_prefix:
-        excitation_names = [
-            i for i in excitation_names if excitation_name_prefix.lower() in i.lower()]
+        excitation_names = [i for i in excitation_names if excitation_name_prefix.lower() in i.lower()]
     for i in excitation_names:
         spar.append("S({},{})".format(i, i))
     return spar
 
+
 @aedt_exception_handler
 def get_insertion_losses_from_prefix(expressions, tx_prefix, rx_prefix):
     """Get the list of all the Insertion Losses from prefix.
@@ -384,17 +379,18 @@ def get_insertion_losses_from_prefix(expressions, tx_prefix, rx_prefix):
 
     """
     spar = []
-    left_list=[]
-    right_list=[]
+    left_list = []
+    right_list = []
     trlist = [i for i in expressions if tx_prefix in i]
     reclist = [i for i in expressions if rx_prefix in i]
-    if len(trlist)!= len(reclist):
+    if len(trlist) != len(reclist):
         print("TX and RX should be same length lists")
         return False
     for i, j in zip(trlist, reclist):
         spar.append("S({},{})".format(i, j))
     return spar
 
+
 @aedt_exception_handler
 def get_insertion_losses_from_lists(txlist, reclist):
     """Get the list of all the Insertion Losses from two list of exctitations (driver and receiver). Optionally prefix can
@@ -415,13 +411,14 @@ def get_insertion_losses_from_lists(txlist, reclist):
 
     """
     spar = []
-    if len(txlist)!= len(reclist):
+    if len(txlist) != len(reclist):
         print("TX and RX should be same length lists")
         return False
     for i, j in zip(txlist, reclist):
         spar.append("S({},{})".format(i, j))
     return spar
 
+
 @aedt_exception_handler
 def get_next_xtalk(expressions, tx_prefix=""):
     """Get the list of all the Near End XTalk a list of excitation. Optionally prefix can
@@ -447,15 +444,18 @@ def get_next_xtalk(expressions, tx_prefix=""):
     else:
         trlist = expressions
     for i in trlist:
-        k = trlist.index(i)+1
+        k = trlist.index(i) + 1
         while k < len(trlist):
             next.append("S({},{})".format(i, trlist[k]))
             k += 1
     return next
 
+
 @aedt_exception_handler
-def get_fext_xtalk_from_list(trlist, reclist,  skip_same_index_couples=True):
-    """Get the list of all the Far End XTalk from 2 lists of exctitations.  If skip_same_index_couples is true, the tx and rx with same index
+def get_fext_xtalk_from_list(trlist, reclist, skip_same_index_couples=True):
+    """Get the list of all the Far End XTalk from 2 lists of exctitations.
+
+    If skip_same_index_couples is true, the tx and rx with same index
     position will be considered insertion losses and excluded from the list
     Example: excitation_names ["1", "2"] ["3","4"] output ["S(1,4)", "S(2,3)"]
 
@@ -477,10 +477,11 @@ def get_fext_xtalk_from_list(trlist, reclist,  skip_same_index_couples=True):
     fext = []
     for i in trlist:
         for k in reclist:
-            if not skip_same_index_couples or reclist.index(k)!= trlist.index(i):
+            if not skip_same_index_couples or reclist.index(k) != trlist.index(i):
                 fext.append("S({},{})".format(i, k))
     return fext
 
+
 @aedt_exception_handler
 def get_fext_xtalk_from_prefix(expressions, tx_prefix, rx_prefix, skip_same_index_couples=True):
     """Get the list of all the Far End XTalk from a list of exctitations and a prefix that will
@@ -511,13 +512,15 @@ def get_fext_xtalk_from_prefix(expressions, tx_prefix, rx_prefix, skip_same_inde
     reclist = [i for i in expressions if rx_prefix in i]
     for i in trlist:
         for k in reclist:
-            if not skip_same_index_couples or reclist.index(k)!= trlist.index(i):
+            if not skip_same_index_couples or reclist.index(k) != trlist.index(i):
                 fext.append("S({},{})".format(i, k))
     return fext
 
+
 @aedt_exception_handler
-def get_worst_curve_from_solution_data(solution_data, freq_min=None, freq_max=None, worst_is_higher=True,
-                                       curve_list=None):
+def get_worst_curve_from_solution_data(
+    solution_data, freq_min=None, freq_max=None, worst_is_higher=True, curve_list=None
+):
     """This method analyze a solution data object with multiple curves and find the worst curve returning its name and
      a ordered dictionary with each curve mean. Actual algorithm simply takes the mean of the magnitued over the
      frequency range
@@ -544,14 +547,14 @@ def get_worst_curve_from_solution_data(solution_data, freq_min=None, freq_max=No
     if not curve_list:
         curve_list = solution_data.expressions
     return_loss_freq = solution_data.sweeps["Freq"]
-    if not freq_min :
+    if not freq_min:
         lower_id = 0
     else:
         lower_id = next(x[0] for x in enumerate(return_loss_freq) if x[1] >= freq_min)
     if not freq_max:
-        higher_id = len(return_loss_freq)-1
+        higher_id = len(return_loss_freq) - 1
     else:
-        if freq_max>= return_loss_freq[-1]:
+        if freq_max >= return_loss_freq[-1]:
             higher_id = len(return_loss_freq) - 1
         else:
             higher_id = next(x[0] for x in enumerate(return_loss_freq) if x[1] >= freq_max)
@@ -559,8 +562,8 @@ def get_worst_curve_from_solution_data(solution_data, freq_min=None, freq_max=No
     dict_means = {}
     for el in curve_list:
         data1 = solution_data.data_magnitude(el)[lower_id:higher_id]
-        mean1 =sum(data1)/len(data1)
-        dict_means[el]= mean1
+        mean1 = sum(data1) / len(data1)
+        dict_means[el] = mean1
     dict_means = dict(sorted(dict_means.items(), key=lambda item: item[1], reverse=worst_is_higher))
     worst_el = next(iter(dict_means))
     return worst_el, dict_means
@@ -584,13 +587,12 @@ def read_touchstone(file_path, verbose=False):
     """
     re_filename = re.compile(r"\.s(?P<ports>\d+)+p", re.I)
     m = re_filename.search(file_path)
-    ports = int(m.group('ports'))
+    ports = int(m.group("ports"))
     if verbose:
         print("File '%s'" % file_path)
-        print("  Number of ports (based on file extension) = %d" % \
-              ports)
+        print("  Number of ports (based on file extension) = %d" % ports)
     file_path = os.path.abspath(file_path)
-    file = open(file_path, 'r')
+    file = open(file_path, "r")
     (frequnit, type, format, z0) = _parse_option_line(file, verbose)
     freqs = []
     matrices = []
@@ -603,7 +605,7 @@ def read_touchstone(file_path, verbose=False):
         pass
     finally:
         file.close()
-    file = open(file_path, 'r')
+    file = open(file_path, "r")
     port_names = _parse_ports_name(file)
     file.close()
     data = TouchstoneData(freqs, matrices, port_names)
@@ -627,11 +629,11 @@ def _parse_ports_name(file):
     -------
 
     """
-    portnames=[]
+    portnames = []
     line = file.readline()
-    while not line.startswith('! Port'):
+    while not line.startswith("! Port"):
         line = file.readline()
-    while line.startswith('! Port'):
+    while line.startswith("! Port"):
         portnames.append(line.split(" = ")[1].strip())
         line = file.readline()
     return portnames
@@ -651,12 +653,7 @@ def _parse_option_line(file, verbose=False):
     -------
 
     """
-    prefix = {
-        '': 1,
-        'K': 1e3,
-        'M': 1e6,
-        'G': 1e9
-    }
+    prefix = {"": 1, "K": 1e3, "M": 1e6, "G": 1e9}
 
     # defaults
     frequnit = 1e9
@@ -666,7 +663,7 @@ def _parse_option_line(file, verbose=False):
     # format of the options line (order is unimportant)
     # <frequency unit> <parameter> <format> R <n>
     line = file.readline()
-    while not line.startswith('#'):
+    while not line.startswith("#"):
         line = file.readline()
 
     options = line[1:].upper().split()
@@ -674,17 +671,17 @@ def _parse_option_line(file, verbose=False):
     i = 0
     while i < len(options):
         option = options[i]
-        if option in ('GHZ', 'MHZ', 'KHZ', 'HZ'):
+        if option in ("GHZ", "MHZ", "KHZ", "HZ"):
             frequnit = prefix[option[:-2]]
-        elif option in ('DB', 'MA', 'RI'):
+        elif option in ("DB", "MA", "RI"):
             format = option
-        elif option in ('S', 'Y', 'Z', 'H', 'G'):
+        elif option in ("S", "Y", "Z", "H", "G"):
             parameter = option
-        elif option == 'R':
+        elif option == "R":
             i += 1
             z0 = float(options[i])
         else:
-            raise ParseError('unrecognized option: {0}'.format(option))
+            raise ParseError("unrecognized option: {0}".format(option))
         i += 1
 
     if verbose:
@@ -709,15 +706,13 @@ def _get_next_line_data(file):
     -------
 
     """
-    line = '!'
-    while _re_comment.search(line) or \
-            _re_options.search(line) or \
-            _re_empty.search(line):
+    line = "!"
+    while _re_comment.search(line) or _re_options.search(line) or _re_empty.search(line):
         line = file.readline()
         if not line:  # end of data
             raise EOFError
     data = []
-    line = line.split('!')[0]
+    line = line.split("!")[0]
     for number in line.split():
         data.append(float(number))
     return data
@@ -749,7 +744,7 @@ def _parse_next_sample(file, ports, format):
     count = 0
 
     port1 = port2 = 1
-    list_data = [None for i in range(ports*ports)]
+    list_data = [None for i in range(ports * ports)]
 
     while True:
         for i in range(int(len(data) / 2)):
@@ -759,12 +754,11 @@ def _parse_next_sample(file, ports, format):
             args[keys[format][1]] = data[index + 1]
             try:
                 if ports == 2:
-                    list_data[(port1-1)*ports + (port2-1)] =parameter(**args)
+                    list_data[(port1 - 1) * ports + (port2 - 1)] = parameter(**args)
                 else:
-                    list_data[(port2-1)*ports + (port1-1)] =parameter(**args)
+                    list_data[(port2 - 1) * ports + (port1 - 1)] = parameter(**args)
             except IndexError:
-                raise Exception("more ports than reported in the file "
-                                "extension")
+                raise Exception("more ports than reported in the file " "extension")
 
             port1 += 1
             if port1 > ports:
