@@ -1,12 +1,10 @@
-import time
-from threading import Thread
-
 import os
-import warnings
 import os.path
+import warnings
 
+from .general_methods import env_path
 
-if os.name == 'posix':
+if os.name == "posix":
     try:
         import subprocessdotnet as subprocess
     except:
@@ -14,13 +12,6 @@ if os.name == 'posix':
 else:
     import subprocess
 
-try:
-    import clr
-except ImportError:
-    warnings.warn("Pythonnet is needed to run pyaedt")
-
-from .general_methods import env_path, env_value
-
 
 class AedtSolve(object):
     """
@@ -38,7 +29,7 @@ class AedtSolve(object):
     >>> solver.solve()
     """
 
-    def __init__(self,aedt_version="2021.1", aedt_installer_path=None):
+    def __init__(self, aedt_version="2021.1", aedt_installer_path=None):
         self._project_path = ""
         self._command = []
         self._nbcores = 4
@@ -67,15 +58,15 @@ class AedtSolve(object):
         return self._exe
 
     @exepath.setter
-    def exepath(self,value):
+    def exepath(self, value):
         self._exe = value
 
     @property
     def command(self):
-        return  self._command
+        return self._command
 
     @command.setter
-    def command(self,value):
+    def command(self, value):
         self._command = value
 
     @property
@@ -83,7 +74,7 @@ class AedtSolve(object):
         return self._nbcores
 
     @nbcores.setter
-    def nbcores(self,value):
+    def nbcores(self, value):
         self._nbcores = value
 
     @property
@@ -91,7 +82,7 @@ class AedtSolve(object):
         return self._ng
 
     @nongraphical.setter
-    def nongraphical(self,value):
+    def nongraphical(self, value):
         self._ng = value
 
     @property
@@ -99,7 +90,7 @@ class AedtSolve(object):
         return self._local
 
     @local.setter
-    def local(self,value):
+    def local(self, value):
         self._local = value
 
     @property
@@ -107,35 +98,36 @@ class AedtSolve(object):
         return self._logfile
 
     @logfile.setter
-    def logfile(self,value):
+    def logfile(self, value):
         self._logfile = value
 
     def solve(self):
         if os.name == "posix":
-            self.command.append(os.path.join(self.installer_path,'ansysedt'))
+            self.command.append(os.path.join(self.installer_path, "ansysedt"))
         else:
-            self.command.append(os.path.join(self.installer_path,'ansysedt.exe'))
+            self.command.append(os.path.join(self.installer_path, "ansysedt.exe"))
         if self.nongraphical:
-            self.command.append('-Batchsolve')
-            self.command.append('-ng')
-            self.command.append('-Monitor')
-            self.command.append('-MachineList')
+            self.command.append("-Batchsolve")
+            self.command.append("-ng")
+            self.command.append("-Monitor")
+            self.command.append("-MachineList")
             # TODO Add batch option support
         if self._local:
             pass
 
-        #self.Command.append('-Auto')
-        self.command.append('-machinelist numcores={}'.format(self.nbcores))
-        self.command.append('-LogFile')
+        # self.Command.append('-Auto')
+        self.command.append("-machinelist numcores={}".format(self.nbcores))
+        self.command.append("-LogFile")
         self.command.append(self.logfile)
         self.command.append(self.projectpath)
         print(self._command)
         p = subprocess.Popen(self.command)
         p.wait()
 
+
 class SiwaveSolve(object):
     def __init__(self, project_path, aedt_version="2021.1", aedt_installer_path=None):
-        self.project_path = project_path
+        self._project_path = project_path
         self._exec_path = ""
         self._nbcores = 4
         self._ng = True
@@ -153,14 +145,14 @@ class SiwaveSolve(object):
         if os.name == "posix":
             self._exe = os.path.join(self.installer_path, executable)
         else:
-            self._exe = os.path.join(self.installer_path, executable+'.exe')
+            self._exe = os.path.join(self.installer_path, executable + ".exe")
 
     @property
     def siwave_exe(self):
         return self._exe
 
     @siwave_exe.setter
-    def siwave_exe(self,value):
+    def siwave_exe(self, value):
         self._exe = value
 
     @property
@@ -168,7 +160,7 @@ class SiwaveSolve(object):
         return self._project_path
 
     @projectpath.setter
-    def projectpath(self,value):
+    def projectpath(self, value):
         self._project_path = value
 
     @property
@@ -176,7 +168,7 @@ class SiwaveSolve(object):
         return self._exec_path
 
     @execfile.setter
-    def execfile(self,value):
+    def execfile(self, value):
         self._exec_path = value
 
     @property
@@ -184,7 +176,7 @@ class SiwaveSolve(object):
         return self._nbcores
 
     @nbcores.setter
-    def nbcores(self,value):
+    def nbcores(self, value):
         self._nbcores = value
 
     @property
@@ -192,27 +184,26 @@ class SiwaveSolve(object):
         return self._ng
 
     @nongraphical.setter
-    def nongraphical(self,value):
+    def nongraphical(self, value):
         self._ng = value
 
     def solve(self):
         # supporting non graphical solve only
         if self.nongraphical:
             if os.name == "posix":
-                exe_path = os.path.join(self.installer_path, 'siwave_ng')
+                exe_path = os.path.join(self.installer_path, "siwave_ng")
             else:
-                exe_path = os.path.join(self.installer_path, 'siwave_ng.exe')
-            exec_file = os.path.splitext(self._project_path)[0] + '.exec'
+                exe_path = os.path.join(self.installer_path, "siwave_ng.exe")
+            exec_file = os.path.splitext(self._project_path)[0] + ".exec"
             if os.path.exists(exec_file):
-                with open(exec_file,"r+") as f:
+                with open(exec_file, "r+") as f:
                     content = f.readlines()
-                    if not 'SetNumCpus' in content:
-                        f.writelines(str.format('SetNumCpus {}', str(self.nbcores)) + '\n')
+                    if not "SetNumCpus" in content:
+                        f.writelines(str.format("SetNumCpus {}", str(self.nbcores)) + "\n")
                         f.writelines("SaveSiw")
                     else:
-                        fstarts = [i for i in range(len(content))
-                                                    if content[i].startswith('SetNumCpus')]
-                        content[fstarts[0]] = str.format('SetNumCpus {}', str(self.nbcores))
+                        fstarts = [i for i in range(len(content)) if content[i].startswith("SetNumCpus")]
+                        content[fstarts[0]] = str.format("SetNumCpus {}", str(self.nbcores))
                         f.close()
                         os.remove(exec_file)
                         f = open(exec_file, "w")
@@ -220,8 +211,8 @@ class SiwaveSolve(object):
             command = [exe_path]
             command.append(self._project_path)
             command.append(exec_file)
-            command.append('-formatOutput -useSubdir')
-            p = subprocess.Popen(command)
+            command.append("-formatOutput -useSubdir")
+            p = subprocess.Popen(" ".join(command))
             p.wait()
 
     def export_3d_cad(self, format_3d="Q3D", output_folder=None, net_list=None):
@@ -241,14 +232,14 @@ class SiwaveSolve(object):
             path to aedt file
         """
         if not output_folder:
-            output_folder = os.path.dirname(self.project_path)
+            output_folder = os.path.dirname(self.projectpath)
         scriptname = os.path.join(output_folder, "export_cad.py")
         with open(scriptname, "w") as f:
             f.write("import os\n")
-            f.write("edbpath = r'{}'\n".format(self.project_path))
+            f.write("edbpath = r'{}'\n".format(self.projectpath))
             f.write("exportOptions = os.path.join(r'{}', 'options.config')\n".format(output_folder))
             f.write("oDoc.ScrImportEDB(edbpath)\n")
-            f.write("oDoc.ScrSaveProjectAs(os.path.join(r'{}','{}'))\n".format(output_folder, 'test.siw'))
+            f.write("oDoc.ScrSaveProjectAs(os.path.join(r'{}','{}'))\n".format(output_folder, "test.siw"))
             if net_list:
                 f.write("allnets = []\n")
                 for el in net_list:
@@ -257,19 +248,18 @@ class SiwaveSolve(object):
                 f.write("    if allnets[i] != 'DUMMY':\n")
                 f.write("        oDoc.ScrSelectNet(allnets[i], 1)\n")
             f.write("oDoc.ScrSetOptionsFor3DModelExport(exportOptions)\n")
-            f.write("q3d_filename = os.path.join(r'{}', '{}')\n".format(
-                output_folder, format_3d+"_siwave.aedt"))
+            f.write("q3d_filename = os.path.join(r'{}', '{}')\n".format(output_folder, format_3d + "_siwave.aedt"))
             f.write("oDoc.ScrExport3DModel('{}', q3d_filename)\n".format(format_3d))
             f.write("oDoc.ScrCloseProject()\n")
             f.write("oApp.Quit()\n")
         if os.name == "posix":
-            _exe = '"'+os.path.join(self.installer_path, "siwave")+'"'
+            _exe = '"' + os.path.join(self.installer_path, "siwave") + '"'
         else:
-            _exe = '"'+os.path.join(self.installer_path, 'siwave.exe')+'"'
+            _exe = '"' + os.path.join(self.installer_path, "siwave.exe") + '"'
         command = [_exe]
         command.append("-RunScriptAndExit")
         command.append(scriptname)
         print(command)
         os.system(" ".join(command))
 
-        return os.path.join(output_folder, format_3d+"_siwave.aedt")
+        return os.path.join(output_folder, format_3d + "_siwave.aedt")
