@@ -6,7 +6,6 @@ import json
 import io
 from .application.Analysis2D import FieldAnalysis2D
 from .application.Analysis3D import FieldAnalysis3D
-from .desktop import exception_to_desktop
 from .generic.DataHandlers import float_units
 from .generic.general_methods import generate_unique_name, aedt_exception_handler
 from .modules.Boundary import BoundaryObject
@@ -43,12 +42,12 @@ class Maxwell(object):
         is ``False``, in which case AEDT is launched in the graphical
         mode. This parameter is ignored when Script is launched within
         AEDT.
-    AlwaysNew : bool, optional
+    new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
         machine. The default is ``True``. This parameter is ignored
         when Script is launched within AEDT.
-    release_on_exit : bool, optional
+    close_on_exit : bool, optional
         Whether to release AEDT on exit. The default is ``False``.
     student_version : bool, optional
         Whether to open the AEDT student version. The default is
@@ -85,7 +84,7 @@ class Maxwell(object):
     def windings(self):
         """Windings."""
         oModule = self.odesign.GetModule("BoundarySetup")
-        windings = oModule.GetExcitationsOfType('Winding Group')
+        windings = oModule.GetExcitationsOfType("Winding Group")
         return list(windings)
 
     @property
@@ -100,7 +99,9 @@ class Maxwell(object):
         return design_file
 
     @aedt_exception_handler
-    def setup_ctrlprog(self, setupname, file_str=None, keep_modifications=False, python_interpreter=None, aedt_lib_dir=None):
+    def setup_ctrlprog(
+        self, setupname, file_str=None, keep_modifications=False, python_interpreter=None, aedt_lib_dir=None
+    ):
         """Configure the transient design setup to run a specific control program.
 
         Parameters
@@ -150,19 +151,26 @@ class Maxwell(object):
                         fo.write(line)
         else:
             if file_str is not None:
-                with io.open(ctl_file, "w", newline='\n') as fo:
+                with io.open(ctl_file, "w", newline="\n") as fo:
                     fo.write(file_str)
                 assert os.path.exists(ctl_file), "Control Program file could not be created."
 
-        self.oanalysis_setup.EditSetup(setupname,
-                          [
-                              "NAME:" + setupname,
-                              "Enabled:=", True,
-                              "UseControlProgram:=", True,
-                              "ControlProgramName:=", ctl_file_compute,
-                              "ControlProgramArg:=", "",
-                              "CallCtrlProgAfterLastStep:=", True
-                          ])
+        self.oanalysis_setup.EditSetup(
+            setupname,
+            [
+                "NAME:" + setupname,
+                "Enabled:=",
+                True,
+                "UseControlProgram:=",
+                True,
+                "ControlProgramName:=",
+                ctl_file_compute,
+                "ControlProgramArg:=",
+                "",
+                "CallCtrlProgAfterLastStep:=",
+                True,
+            ],
+        )
 
         return True
 
@@ -186,19 +194,14 @@ class Maxwell(object):
         """
         EddyVector = ["NAME:EddyEffectVector"]
         for obj in object_list:
-            EddyVector.append([
-                "NAME:Data",
-                "Object Name:=", obj,
-                "Eddy Effect:=", activate
-            ])
+            EddyVector.append(["NAME:Data", "Object Name:=", obj, "Eddy Effect:=", activate])
 
         oModule = self.odesign.GetModule("BoundarySetup")
         oModule.SetEddyEffect(["NAME:Eddy Effect Setting", EddyVector])
         return True
 
     @aedt_exception_handler
-    def assign_current(self, object_list, amplitude=1, phase="0deg", solid=True, swap_direction=False,
-                       name=None):
+    def assign_current(self, object_list, amplitude=1, phase="0deg", solid=True, swap_direction=False, name=None):
         """Assign the source of the current.
 
         Parameters
@@ -231,14 +234,26 @@ class Maxwell(object):
         if self.is3d:
             if type(object_list[0]) is int:
                 props = OrderedDict(
-                    {"Faces": object_list, "Current": amplitude, "IsSolid": solid, "Point out of terminal": swap_direction})
+                    {
+                        "Faces": object_list,
+                        "Current": amplitude,
+                        "IsSolid": solid,
+                        "Point out of terminal": swap_direction,
+                    }
+                )
             else:
                 props = OrderedDict(
-                    {"Objects": object_list, "Current": amplitude,"Phase":phase, "IsSolid": solid, "Point out of terminal": swap_direction})
+                    {
+                        "Objects": object_list,
+                        "Current": amplitude,
+                        "Phase": phase,
+                        "IsSolid": solid,
+                        "Point out of terminal": swap_direction,
+                    }
+                )
         else:
             if type(object_list[0]) is str:
-                props = OrderedDict(
-                    {"Objects": object_list, "Current": amplitude,"IsPositive": swap_direction})
+                props = OrderedDict({"Objects": object_list, "Current": amplitude, "IsPositive": swap_direction})
             else:
                 self._messenger.add_warning_message("Input has to be a 2D Object")
                 return False
@@ -311,8 +326,7 @@ class Maxwell(object):
             name = generate_unique_name("VoltageDrop")
         face_list = self.modeler._convert_list_to_ids(face_list)
 
-        props = OrderedDict({"Faces": face_list, "Voltage Drop": amplitude,
-                            "Point out of terminal": swap_direction})
+        props = OrderedDict({"Faces": face_list, "Voltage Drop": amplitude, "Point out of terminal": swap_direction})
         bound = BoundaryObject(self, name, props, "VoltageDrop")
         if bound.create():
             self.boundaries.append(bound)
@@ -320,8 +334,18 @@ class Maxwell(object):
         return False
 
     @aedt_exception_handler
-    def assign_winding(self, coil_terminals=None, winding_type="Current", is_solid=True, current_value=1, res=0, ind=0, voltage=0,
-                       parallel_branches=1, name=None):
+    def assign_winding(
+        self,
+        coil_terminals=None,
+        winding_type="Current",
+        is_solid=True,
+        current_value=1,
+        res=0,
+        ind=0,
+        voltage=0,
+        parallel_branches=1,
+        name=None,
+    ):
         """Assign a winding to a Maxwell design.
 
         Parameters
@@ -357,17 +381,25 @@ class Maxwell(object):
         if not name:
             name = generate_unique_name("Winding")
 
-        props = OrderedDict({"Type": winding_type, "IsSolid": is_solid, "Current": str(current_value) + "A",
-                             "Resistance": str(res) + "ohm", "Inductance": str(ind) + "H",
-                             "Voltage": str(voltage) + "V", "ParallelBranchesNum": str(parallel_branches)})
+        props = OrderedDict(
+            {
+                "Type": winding_type,
+                "IsSolid": is_solid,
+                "Current": str(current_value) + "A",
+                "Resistance": str(res) + "ohm",
+                "Inductance": str(ind) + "H",
+                "Voltage": str(voltage) + "V",
+                "ParallelBranchesNum": str(parallel_branches),
+            }
+        )
         bound = BoundaryObject(self, name, props, "Winding")
         if bound.create():
             self.boundaries.append(bound)
             if type(coil_terminals) is not list:
                 coil_terminals = [coil_terminals]
-            coil_names=[]
+            coil_names = []
             for coil in coil_terminals:
-                c=self.assign_coil(coil)
+                c = self.assign_coil(coil)
                 if c:
                     coil_names.append(c.name)
 
@@ -432,21 +464,23 @@ class Maxwell(object):
         if type(input_object[0]) is str:
             if self.modeler._is3d:
                 props2 = OrderedDict(
-                    {"Objects": input_object, "Conductor number": str(conductor_number), "Point out of terminal": point})
+                    {"Objects": input_object, "Conductor number": str(conductor_number), "Point out of terminal": point}
+                )
                 bound = BoundaryObject(self, name, props2, "CoilTerminal")
             else:
                 props2 = OrderedDict(
-                    {"Objects": input_object, "Conductor number": str(conductor_number), "PolarityType": polarity})
+                    {"Objects": input_object, "Conductor number": str(conductor_number), "PolarityType": polarity}
+                )
                 bound = BoundaryObject(self, name, props2, "Coil")
         else:
             if self.modeler._is3d:
                 props2 = OrderedDict(
-                    {"Faces": input_object, "Conductor number": str(conductor_number), "Point out of terminal": point})
+                    {"Faces": input_object, "Conductor number": str(conductor_number), "Point out of terminal": point}
+                )
                 bound = BoundaryObject(self, name, props2, "CoilTerminal")
 
             else:
-                self._messenger.add_warning_message(
-                    "Face Selection is not allowed in Maxwell 2D. Provide a 2D object.")
+                self._messenger.add_warning_message("Face Selection is not allowed in Maxwell 2D. Provide a 2D object.")
                 return False
         if bound.create():
             self.boundaries.append(bound)
@@ -480,22 +514,25 @@ class Maxwell(object):
         if self.design_type == "Maxwell 3D":
             self.o_maxwell_parameters.AssignForce(
                 [
-                    "NAME:"+force_name,
-                    "Reference CS:=", reference_cs,
-                    "Is Virtual:="	, is_virtual,
-                    "Objects:="		, input_object
-                ])
+                    "NAME:" + force_name,
+                    "Reference CS:=",
+                    reference_cs,
+                    "Is Virtual:=",
+                    is_virtual,
+                    "Objects:=",
+                    input_object,
+                ]
+            )
         else:
             self.o_maxwell_parameters.AssignForce(
-                [
-                    "NAME:"+force_name,
-                    "Reference CS:=", reference_cs,
-                    "Objects:="		, input_object
-                ])
+                ["NAME:" + force_name, "Reference CS:=", reference_cs, "Objects:=", input_object]
+            )
         return True
 
     @aedt_exception_handler
-    def assign_torque(self, input_object, reference_cs="Global", is_positive=True, is_virtual=True, axis="Z", torque_name=None):
+    def assign_torque(
+        self, input_object, reference_cs="Global", is_positive=True, is_virtual=True, axis="Z", torque_name=None
+    ):
         """Assign a torque to one or more objects.
 
         Parameters
@@ -524,12 +561,32 @@ class Maxwell(object):
             torque_name = generate_unique_name("Torque")
         if self.design_type == "Maxwell 3D":
             self.o_maxwell_parameters.AssignTorque(
-                ["NAME:" + torque_name, "Is Virtual:=", is_virtual, "Coordinate System:=", reference_cs, "Axis:=", axis,
-                 "Is Positive:=", is_positive, "Objects:=", input_object])
+                [
+                    "NAME:" + torque_name,
+                    "Is Virtual:=",
+                    is_virtual,
+                    "Coordinate System:=",
+                    reference_cs,
+                    "Axis:=",
+                    axis,
+                    "Is Positive:=",
+                    is_positive,
+                    "Objects:=",
+                    input_object,
+                ]
+            )
         else:
             self.o_maxwell_parameters.AssignTorque(
-                ["NAME:" + torque_name, "Coordinate System:=", reference_cs,
-                 "Is Positive:=", is_positive, "Objects:=", input_object])
+                [
+                    "NAME:" + torque_name,
+                    "Coordinate System:=",
+                    reference_cs,
+                    "Is Positive:=",
+                    is_positive,
+                    "Objects:=",
+                    input_object,
+                ]
+            )
         return True
 
     @aedt_exception_handler
@@ -559,10 +616,14 @@ class Maxwell(object):
         self.o_maxwell_parameters.AssignForce(
             [
                 "NAME:" + force_name,
-                "Reference CS:=", reference_cs,
-                "Is Virtual:=", is_virtual,
-                "Objects:="	, input_object
-            ])
+                "Reference CS:=",
+                reference_cs,
+                "Is Virtual:=",
+                is_virtual,
+                "Objects:=",
+                input_object,
+            ]
+        )
         return True
 
     @aedt_exception_handler
@@ -621,29 +682,16 @@ class Maxwell(object):
                 "NAME:AllTabs",
                 [
                     "NAME:Maxwell2D",
-                    [
-                        "NAME:PropServers",
-                        "ModelSetup:" + motion_setup
-                    ],
-                    [
-                        "NAME:ChangedProps",
-                        [
-                            "NAME:Initial Position",
-                            "Value:=", val
-                        ]
-                    ]
-                ]
-            ])
+                    ["NAME:PropServers", "ModelSetup:" + motion_setup],
+                    ["NAME:ChangedProps", ["NAME:Initial Position", "Value:=", val]],
+                ],
+            ]
+        )
         return True
 
     def __enter__(self):
         return self
 
-    def __exit__(self, ex_type, ex_value, ex_traceback):
-        """Push exit up to parent object Design."""
-        if ex_type:
-            exception_to_desktop(self, ex_value, ex_traceback)
-
 
 class Maxwell3d(Maxwell, FieldAnalysis3D, object):
     """Provides the Maxwell 3D application interface.
@@ -678,12 +726,12 @@ class Maxwell3d(Maxwell, FieldAnalysis3D, object):
         is ``False``, in which case AEDT is launched in the graphical
         mode. This parameter is ignored when Script is launched within
         AEDT.
-    AlwaysNew : bool, optional
+    new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
         machine. The default is ``True``. This parameter is ignored
         when Script is launched within AEDT.
-    release_on_exit : bool, optional
+    close_on_exit : bool, optional
         Whether to release AEDT on exit. The default is ``False``.
     student_version : bool, optional
         Whether to open the AEDT student version. The default is
@@ -710,16 +758,37 @@ class Maxwell3d(Maxwell, FieldAnalysis3D, object):
     @property  # for legacy purposes
     def dim(self):
         """Dimensions."""
-        return '3D'
+        return "3D"
 
-    def __init__(self, projectname=None, designname=None, solution_type=None, setup_name=None,
-                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False,student_version=False):
+    def __init__(
+        self,
+        projectname=None,
+        designname=None,
+        solution_type=None,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=False,
+        close_on_exit=False,
+        student_version=False,
+    ):
         """
         Initialize the `Maxwell` class.
         """
         self.is3d = True
-        FieldAnalysis3D.__init__(self, "Maxwell 3D", projectname, designname, solution_type, setup_name,
-                                 specified_version, NG, AlwaysNew, release_on_exit, student_version)
+        FieldAnalysis3D.__init__(
+            self,
+            "Maxwell 3D",
+            projectname,
+            designname,
+            solution_type,
+            setup_name,
+            specified_version,
+            non_graphical,
+            new_desktop_session,
+            close_on_exit,
+            student_version,
+        )
         Maxwell.__init__(self)
 
 
@@ -749,18 +818,21 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
         nothing is used.
     specified_version: str, optional
         Version of AEDT to use. The default is ``None``, in which case
-        the active version or latest installed version is used. This parameter is ignored when Script is launched within AEDT.
+        the active version or latest installed version is used.
+        This parameter is ignored when Script is launched within AEDT.
     NG : bool, optional
         Whether to launch AEDT in the non-graphical mode. The default
-        is ``False``, in which case AEDT is launched in the graphical mode. This parameter is ignored when Script is launched within AEDT.
-    AlwaysNew : bool, optional
+        is ``False``, in which case AEDT is launched in the graphical mode.
+        This parameter is ignored when Script is launched within AEDT.
+    new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
         machine. The default is ``True``. This parameter is ignored when Script is launched within AEDT.
-    release_on_exit : bool, optional
+    close_on_exit : bool, optional
         Whether to release AEDT on exit. The default is ``False``.
     student_version : bool, optional
-        Whether to open the AEDT student version. The default is ``False``. This parameter is ignored when Script is launched within AEDT.
+        Whether to open the AEDT student version. The default is ``False``.
+        This parameter is ignored when Script is launched within AEDT.
 
     Examples
     --------
@@ -794,18 +866,39 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
         """Geometry mode."""
         return self.odesign.GetGeometryMode()
 
-    def __init__(self, projectname=None, designname=None, solution_type=None, setup_name=None,
-                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
+    def __init__(
+        self,
+        projectname=None,
+        designname=None,
+        solution_type=None,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=False,
+        close_on_exit=False,
+        student_version=False,
+    ):
         self.is3d = False
-        FieldAnalysis2D.__init__(self, "Maxwell 2D", projectname, designname, solution_type, setup_name,
-                                 specified_version, NG, AlwaysNew, release_on_exit, student_version)
+        FieldAnalysis2D.__init__(
+            self,
+            "Maxwell 2D",
+            projectname,
+            designname,
+            solution_type,
+            setup_name,
+            specified_version,
+            non_graphical,
+            new_desktop_session,
+            close_on_exit,
+            student_version,
+        )
         Maxwell.__init__(self)
 
     @aedt_exception_handler
     def get_model_depth(self):
         """Get model depth."""
         if "ModelDepth" in self.design_properties:
-            value_str=self.design_properties["ModelDepth"]
+            value_str = self.design_properties["ModelDepth"]
             try:
                 a = float_units(value_str)
             except:
@@ -840,10 +933,10 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
             if isinstance(obj, dict):
                 return {convert(key): convert(value) for key, value in obj.items()}
             return obj
+
         solid_bodies = self.modeler.solid_bodies
         if objectfilter:
-            solid_ids = [i for i,j in self.modeler.primitives.object_id_dict.items()
-                                                                                   if j.name in objectfilter]
+            solid_ids = [i for i, j in self.modeler.primitives.object_id_dict.items() if j.name in objectfilter]
         else:
             solid_ids = [i for i in list(self.modeler.primitives.object_id_dict.keys())]
         model_depth = self.get_model_depth()
@@ -860,11 +953,11 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
             "LineList": self.modeler.vertex_data_of_lines(linefilter),
             "VarList": self.variable_manager.variable_names,
             "Setups": self.existing_analysis_setups,
-            "MaterialProperties": self.get_object_material_properties(solid_bodies)
+            "MaterialProperties": self.get_object_material_properties(solid_bodies),
         }
 
         design_file = os.path.join(self.working_directory, "design_data.json")
-        with open(design_file, 'w') as fps:
+        with open(design_file, "w") as fps:
             json.dump(convert(self.design_data), fps, indent=4)
         return True
 
@@ -879,12 +972,12 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
 
         """
         design_file = os.path.join(self.working_directory, "design_data.json")
-        with open(design_file, 'r') as fps:
+        with open(design_file, "r") as fps:
             design_data = json.load(fps)
         return design_data
 
     @aedt_exception_handler
-    def assign_balloon(self, edge_list, bound_name= None):
+    def assign_balloon(self, edge_list, bound_name=None):
         """Assign a balloon boundary to a list of edges.
 
         Parameters
@@ -905,8 +998,7 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
         if not bound_name:
             bound_name = generate_unique_name("Balloon")
 
-        props2 = OrderedDict(
-            {"Edges": edge_list})
+        props2 = OrderedDict({"Edges": edge_list})
         bound = BoundaryObject(self, bound_name, props2, "Balloon")
 
         if bound.create():
@@ -936,16 +1028,63 @@ class Maxwell2d(Maxwell, FieldAnalysis2D, object):
         input_edge = self.modeler._convert_list_to_ids(input_edge)
 
         if not bound_name:
-            bound_name=generate_unique_name("Vector")
+            bound_name = generate_unique_name("Vector")
         if type(input_edge[0]) is str:
-            props2 = OrderedDict(
-                {"Objects": input_edge, "Value": str(vectorvalue), "CoordinateSystem": ""})
+            props2 = OrderedDict({"Objects": input_edge, "Value": str(vectorvalue), "CoordinateSystem": ""})
         else:
-            props2 = OrderedDict(
-                {"Edges": input_edge, "Value": str(vectorvalue), "CoordinateSystem": ""})
+            props2 = OrderedDict({"Edges": input_edge, "Value": str(vectorvalue), "CoordinateSystem": ""})
         bound = BoundaryObject(self, bound_name, props2, "VectorPotential")
 
         if bound.create():
             self.boundaries.append(bound)
             return bound
         return False
+
+    @aedt_exception_handler
+    def assign_master_slave(self, master_edge, slave_edge, reverse_master=False, reverse_slave=False,
+                            same_as_master=True, bound_name=None):
+        """Assign master and slave boundary conditions to two edges of the same object.
+
+        Parameters
+        ----------
+        master_edge : int
+            ID of the master edge.
+        slave_edge : int
+            ID of the slave edge.
+        reverse_master : bool, optional
+            Whether to reverse the master edge to the V direction. The default is ``False``.
+        reverse_slave : bool, optional
+            Whether to reverse the master edge to the U direction. The default is ``False``.
+        same_as_master : bool, optional
+            Whether the B-Field of the slave edge and master edge are the same. The default is ``True``.
+        bound_name : str, optional
+            Name of the master boundary. The name of the slave boundary will have a ``_dep`` suffix.
+
+        Returns
+        -------
+        :class:`pyaedt.modules.Boundary.BoundaryObject`, :class:`pyaedt.modules.Boundary.BoundaryObject`
+            Master and slave objects.
+
+        """
+        master_edge = self.modeler._convert_list_to_ids(master_edge)
+        slave_edge = self.modeler._convert_list_to_ids(slave_edge)
+        if not bound_name:
+            bound_name_m = generate_unique_name("Independent")
+            bound_name_s = generate_unique_name("Dependent")
+        else:
+            bound_name_m = bound_name
+            bound_name_s = bound_name + "_dep"
+        props2 = OrderedDict({"Edges": master_edge, "ReverseV": reverse_master})
+        bound = BoundaryObject(self, bound_name_m, props2, "Independent")
+        if bound.create():
+            self.boundaries.append(bound)
+
+            props2 = OrderedDict({"Edges": slave_edge, "ReverseU": reverse_slave, "Independent": bound_name_m,
+                                  "SameAsMaster": same_as_master})
+            bound2 = BoundaryObject(self, bound_name_s, props2, "Independent")
+            if bound2.create():
+                self.boundaries.append(bound2)
+                return bound, bound2
+            else:
+                return bound, False
+        return False, False
