@@ -3,7 +3,6 @@
 from __future__ import absolute_import
 
 from .application.Analysis3D import FieldAnalysis3D
-from .desktop import exception_to_desktop
 from .generic.general_methods import generate_unique_name, aedt_exception_handler
 from .modules.Boundary import BoundaryObject
 from collections import OrderedDict
@@ -32,18 +31,21 @@ class Mechanical(FieldAnalysis3D, object):
         nothing is used.
     specified_version: str, optional
         Version of AEDT to use. The default is ``None``, in which case
-        the active version or latest installed version is used. This parameter is ignored when Script is launched within AEDT.
+        the active version or latest installed version is used.
+        This parameter is ignored when Script is launched within AEDT.
     NG : bool, optional
         Whether to launch AEDT in the non-graphical mode. The default
-        is``False``, in which case AEDT is launched in the graphical mode. This parameter is ignored when Script is launched within AEDT.
-    AlwaysNew : bool, optional
+        is``False``, in which case AEDT is launched in the graphical mode.
+        This parameter is ignored when Script is launched within AEDT.
+    new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
         machine. The default is ``True``. This parameter is ignored when Script is launched within AEDT.
-    release_on_exit : bool, optional
+    close_on_exit : bool, optional
         Whether to release AEDT on exit.
     student_version : bool, optional
-        Whether to open the AEDT student version. The default is ``False``. This parameter is ignored when Script is launched within AEDT.
+        Whether to open the AEDT student version. The default is ``False``.
+        This parameter is ignored when Script is launched within AEDT.
 
     Examples
     --------
@@ -77,23 +79,48 @@ class Mechanical(FieldAnalysis3D, object):
 
     """
 
-    def __init__(self, projectname=None, designname=None, solution_type=None, setup_name=None,
-                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
+    def __init__(
+        self,
+        projectname=None,
+        designname=None,
+        solution_type=None,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=False,
+        close_on_exit=False,
+        student_version=False,
+    ):
 
-        FieldAnalysis3D.__init__(self, "Mechanical", projectname, designname, solution_type, setup_name,
-                                 specified_version, NG, AlwaysNew, release_on_exit, student_version)
+        FieldAnalysis3D.__init__(
+            self,
+            "Mechanical",
+            projectname,
+            designname,
+            solution_type,
+            setup_name,
+            specified_version,
+            non_graphical,
+            new_desktop_session,
+            close_on_exit,
+            student_version,
+        )
 
     def __enter__(self):
         return self
 
-    def __exit__(self, ex_type, ex_value, ex_traceback):
-        """Push exit up to parent object Design."""
-        if ex_type:
-            exception_to_desktop(self, ex_value, ex_traceback)
-
     @aedt_exception_handler
-    def assign_em_losses(self, designname="HFSSDesign1", setupname="Setup1", sweepname="LastAdaptive", map_frequency=None,
-                         surface_objects=[], source_project_name=None, paramlist=[], object_list=[]):
+    def assign_em_losses(
+        self,
+        designname="HFSSDesign1",
+        setupname="Setup1",
+        sweepname="LastAdaptive",
+        map_frequency=None,
+        surface_objects=[],
+        source_project_name=None,
+        paramlist=[],
+        object_list=[],
+    ):
         """Map EM losses to a Mechanical design.
 
         Parameters
@@ -147,27 +174,44 @@ class Mechanical(FieldAnalysis3D, object):
             argparam[el] = self.available_variations.nominal_w_values_dict[el]
 
         for el in paramlist:
-            argparam[el]=el
+            argparam[el] = el
 
         props = OrderedDict(
-            {"Objects": allObjects, "allObjects": False, "Project": projname, "projname": "ElectronicsDesktop",
-             "Design": designname, "Soln": setupname + " : " + sweepname, "Params": argparam,
-             "ForceSourceToSolve": True, "PreservePartnerSoln": True, "PathRelativeTo": "TargetProject"})
+            {
+                "Objects": allObjects,
+                "allObjects": False,
+                "Project": projname,
+                "projname": "ElectronicsDesktop",
+                "Design": designname,
+                "Soln": setupname + " : " + sweepname,
+                "Params": argparam,
+                "ForceSourceToSolve": True,
+                "PreservePartnerSoln": True,
+                "PathRelativeTo": "TargetProject",
+            }
+        )
         if intr:
-            props["Intrinsics"]= intr
-            props["SurfaceOnly"]= surfaces
+            props["Intrinsics"] = intr
+            props["SurfaceOnly"] = surfaces
 
         name = generate_unique_name("EMLoss")
         bound = BoundaryObject(self, name, props, "EMLoss")
         if bound.create():
             self.boundaries.append(bound)
-            self._messenger.add_info_message('EM losses mapped from design {}.'.format(designname))
+            self._messenger.add_info_message("EM losses mapped from design {}.".format(designname))
             return bound
         return False
 
     @aedt_exception_handler
-    def assign_thermal_map(self, object_list, designname="IcepakDesign1", setupname="Setup1", sweepname="SteadyState",
-                           source_project_name=None, paramlist=[]):
+    def assign_thermal_map(
+        self,
+        object_list,
+        designname="IcepakDesign1",
+        setupname="Setup1",
+        sweepname="SteadyState",
+        source_project_name=None,
+        paramlist=[],
+    ):
         """Map thermal losses to a Mechanical design.
 
         .. note::
@@ -219,23 +263,33 @@ class Mechanical(FieldAnalysis3D, object):
             argparam[el] = el
 
         props = OrderedDict(
-            {"Objects": allObjects, "Uniform": False, "Project": projname, "Product": "ElectronicsDesktop",
-             "Design": designname, "Soln": setupname + " : " + sweepname, "Params": argparam,
-             "ForceSourceToSolve": True, "PreservePartnerSoln": True, "PathRelativeTo": "TargetProject"})
+            {
+                "Objects": allObjects,
+                "Uniform": False,
+                "Project": projname,
+                "Product": "ElectronicsDesktop",
+                "Design": designname,
+                "Soln": setupname + " : " + sweepname,
+                "Params": argparam,
+                "ForceSourceToSolve": True,
+                "PreservePartnerSoln": True,
+                "PathRelativeTo": "TargetProject",
+            }
+        )
 
         name = generate_unique_name("ThermalLink")
         bound = BoundaryObject(self, name, props, "ThermalCondition")
         if bound.create():
             self.boundaries.append(bound)
-            self._messenger.add_info_message(
-                'Thermal conditions are mapped from design {}.'.format(designname))
+            self._messenger.add_info_message("Thermal conditions are mapped from design {}.".format(designname))
             return bound
 
         return True
 
     @aedt_exception_handler
-    def assign_uniform_convection(self, objects_list, convection_value, convection_unit="w_per_m2kel",
-                                  temperature="AmbientTemp", boundary_name=""):
+    def assign_uniform_convection(
+        self, objects_list, convection_value, convection_unit="w_per_m2kel", temperature="AmbientTemp", boundary_name=""
+    ):
         """Assign a uniform convection to the face list.
 
         Parameters
@@ -274,7 +328,7 @@ class Mechanical(FieldAnalysis3D, object):
 
         if not boundary_name:
             boundary_name = generate_unique_name("Convection")
-        bound = BoundaryObject(self, boundary_name, props, 'Convection')
+        bound = BoundaryObject(self, boundary_name, props, "Convection")
         if bound.create():
             self.boundaries.append(bound)
             return bound
@@ -317,14 +371,14 @@ class Mechanical(FieldAnalysis3D, object):
 
         if not boundary_name:
             boundary_name = generate_unique_name("Temp")
-        bound = BoundaryObject(self, boundary_name, props, 'Temperature')
+        bound = BoundaryObject(self, boundary_name, props, "Temperature")
         if bound.create():
             self.boundaries.append(bound)
             return bound
         return False
 
     @aedt_exception_handler
-    def assign_frictionless_support(self, objects_list,  boundary_name=""):
+    def assign_frictionless_support(self, objects_list, boundary_name=""):
         """Assign a Mechanical frictionless support.
 
         .. note::
@@ -345,8 +399,7 @@ class Mechanical(FieldAnalysis3D, object):
         """
 
         if not (self.solution_type == "Structural" or self.solution_type == "Modal"):
-            self._messenger.add_error_message(
-                "This method works only in Mechanical Structural Solution")
+            self._messenger.add_error_message("This method works only in Mechanical Structural Solution")
             return False
         props = {}
         objects_list = self.modeler._convert_list_to_ids(objects_list)
@@ -359,14 +412,14 @@ class Mechanical(FieldAnalysis3D, object):
 
         if not boundary_name:
             boundary_name = generate_unique_name("Temp")
-        bound = BoundaryObject(self, boundary_name, props, 'Frictionless')
+        bound = BoundaryObject(self, boundary_name, props, "Frictionless")
         if bound.create():
             self.boundaries.append(bound)
             return bound
         return False
 
     @aedt_exception_handler
-    def assign_fixed_support(self, objects_list,  boundary_name=""):
+    def assign_fixed_support(self, objects_list, boundary_name=""):
         """Assign a Mechanical fixed support.
 
         .. note::
@@ -386,8 +439,7 @@ class Mechanical(FieldAnalysis3D, object):
 
         """
         if not (self.solution_type == "Structural" or self.solution_type == "Modal"):
-            self._messenger.add_error_message(
-                "This method works only in a Mechanical structural solution.")
+            self._messenger.add_error_message("This method works only in a Mechanical structural solution.")
             return False
         props = {}
         objects_list = self.modeler._convert_list_to_ids(objects_list)
@@ -397,7 +449,7 @@ class Mechanical(FieldAnalysis3D, object):
 
         if not boundary_name:
             boundary_name = generate_unique_name("Temp")
-        bound = BoundaryObject(self, boundary_name, props, 'FixedSupport')
+        bound = BoundaryObject(self, boundary_name, props, "FixedSupport")
         if bound.create():
             self.boundaries.append(bound)
             return bound
@@ -414,7 +466,7 @@ class Mechanical(FieldAnalysis3D, object):
 
         """
         setup_list = self.existing_analysis_setups
-        sweep_list=[]
+        sweep_list = []
         for el in setup_list:
             sweep_list.append(el + " : Solution")
         return sweep_list
