@@ -24,11 +24,49 @@ class MatProperties(object):
     Internal names are used in scripts, and XML names are used in the XML syntax.
 
     """
-    aedtname =     ['permittivity', 'permeability', 'conductivity', 'dielectric_loss_tangent', 'magnetic_loss_tangent', 'thermal_conductivity', 'mass_density', 'specific_heat', 'thermal_expansion_coefficient', 'youngs_modulus',   'poissons_ratio',   'diffusivity', 'molecular_mass', 'viscosity', 'core_loss_kh', 'core_loss_kc', 'core_loss_ke']
-    defaultvalue = [1.0,             1.0,            0,              0,                         0,                       0.01,                      0,              0,               0,                               0,                  0,                  0.8,         0,                   0,                 0,                   0,                      0,                          0]
-    defaultunit  = [None,            None,          '[siemens m^-1]', None,                     None,                   '[W m^-1 C^-1]',        '[Kg m^-3]',    '[J Kg^-1 C^-1]', '[C^-1]',                       '[Pa]',             None,               None,               None,               None,               None,           None,                  None,                       None]
-    diel_order =   [3, 0, 1, 4, 5, 6, 7, 8, 9, 10, 11, 1]
-    cond_order =   [2, 0, 1, 4, 5, 6, 7, 8, 9, 10, 11, 3]
+
+    aedtname = [
+        "permittivity",
+        "permeability",
+        "conductivity",
+        "dielectric_loss_tangent",
+        "magnetic_loss_tangent",
+        "thermal_conductivity",
+        "mass_density",
+        "specific_heat",
+        "thermal_expansion_coefficient",
+        "youngs_modulus",
+        "poissons_ratio",
+        "diffusivity",
+        "molecular_mass",
+        "viscosity",
+        "core_loss_kh",
+        "core_loss_kc",
+        "core_loss_ke",
+    ]
+    defaultvalue = [1.0, 1.0, 0, 0, 0, 0.01, 0, 0, 0, 0, 0, 0.8, 0, 0, 0, 0, 0, 0]
+    defaultunit = [
+        None,
+        None,
+        "[siemens m^-1]",
+        None,
+        None,
+        "[W m^-1 C^-1]",
+        "[Kg m^-3]",
+        "[J Kg^-1 C^-1]",
+        "[C^-1]",
+        "[Pa]",
+        None,
+        None,
+        None,
+        None,
+        None,
+        None,
+        None,
+        None,
+    ]
+    diel_order = [3, 0, 1, 4, 5, 6, 7, 8, 9, 10, 11, 1]
+    cond_order = [2, 0, 1, 4, 5, 6, 7, 8, 9, 10, 11, 3]
 
     @classmethod
     def get_defaultunit(cls, aedtname=None):
@@ -70,6 +108,7 @@ class MatProperties(object):
         else:
             raise TypeError("get_defaultunit: Either the full name or category name must be defined.")
 
+
 class SurfMatProperties(object):
     """Contains a list of constant names for all surface materials with
     mappings to their internal XML names.
@@ -77,9 +116,15 @@ class SurfMatProperties(object):
     Internal names are used in scripts, and XML names are used in the XML syntax.
 
     """
-    aedtname =     ['surface_emissivity', 'surface_roughness', 'surface_diffuse_absorptance', 'surface_incident_absorptance']
-    defaultvalue = [1.0,             0,            0.4,              0.4]
-    defaultunit  = [None,            '[m]',          None, None]
+
+    aedtname = [
+        "surface_emissivity",
+        "surface_roughness",
+        "surface_diffuse_absorptance",
+        "surface_incident_absorptance",
+    ]
+    defaultvalue = [1.0, 0, 0.4, 0.4]
+    defaultunit = [None, "[m]", None, None]
 
     @classmethod
     def get_defaultunit(cls, aedtname=None):
@@ -124,17 +169,20 @@ class SurfMatProperties(object):
 
 class ClosedFormTM(object):
     """Manges closed-form thermal modifiers."""
-    Tref = '22cel'
+
+    Tref = "22cel"
     C1 = 0
     C2 = 0
-    TL = '-273.15cel'
-    TU = '1000cel'
+    TL = "-273.15cel"
+    TU = "1000cel"
     autocalculation = True
     TML = 1000
     TMU = 1000
 
+
 class Dataset(object):
     """Manages datasets."""
+
     ds = []
     unitx = ""
     unity = ""
@@ -144,9 +192,10 @@ class Dataset(object):
     namey = ""
     namez = None
 
+
 class BasicValue(object):
-    """Manages thermal modifier calculations.
-    """
+    """Manages thermal modifier calculations."""
+
     value = None
     dataset = None
     thermalmodifier = None
@@ -175,14 +224,14 @@ class MatProperty(object):
     def __init__(self, parent, name, val=None, thermalmodifier=None):
         self._parent = parent
         self._type = "simple"
-        self.name =name
+        self.name = name
         self._property_value = [BasicValue()]
         self._unit = None
-        if val is not None and isinstance(val,(str, float, int)):
+        if val is not None and isinstance(val, (str, float, int)):
             self.value = val
         elif val is not None and val["property_type"] == "AnisoProperty":
             self.type = "anisotropic"
-            self.value = [val["component1"],val["component2"], val["component3"]]
+            self.value = [val["component1"], val["component2"], val["component3"]]
         if not isinstance(thermalmodifier, list):
             thermalmodifier = [thermalmodifier]
         for tm in thermalmodifier:
@@ -277,7 +326,7 @@ class MatProperty(object):
             for i in thermal_value:
                 self._add_thermal_modifier(i, thermal_value.index(i))
 
-    def _add_thermal_modifier(self,formula, index):
+    def _add_thermal_modifier(self, formula, index):
         """Add a thermal modifier.
 
         Parameters
@@ -293,46 +342,104 @@ class MatProperty(object):
 
         """
         if "ModifierData" not in self._parent._props:
-            tm = OrderedDict({'Property:': self.name, 'Index:': index, "prop_modifier": "thermal_modifier",
-                              "use_free_form": True, "free_form_value": formula})
-            self._parent._props["ModifierData"] = OrderedDict({"ThermalModifierData": OrderedDict(
-                {"modifier_data": 'thermal_modifier_data',
-                 "all_thermal_modifiers": OrderedDict({"one_thermal_modifier": tm})})})
+            tm = OrderedDict(
+                {
+                    "Property:": self.name,
+                    "Index:": index,
+                    "prop_modifier": "thermal_modifier",
+                    "use_free_form": True,
+                    "free_form_value": formula,
+                }
+            )
+            self._parent._props["ModifierData"] = OrderedDict(
+                {
+                    "ThermalModifierData": OrderedDict(
+                        {
+                            "modifier_data": "thermal_modifier_data",
+                            "all_thermal_modifiers": OrderedDict({"one_thermal_modifier": tm}),
+                        }
+                    )
+                }
+            )
         else:
             for tmname in self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"]:
-                if isinstance(self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname], list):
+                if isinstance(
+                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname], list
+                ):
                     found = False
-                    for tm in self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname]:
-                        if self.name == tm['Property:'] and index == tm['Index:']:
+                    for tm in self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][
+                        tmname
+                    ]:
+                        if self.name == tm["Property:"] and index == tm["Index:"]:
                             found = True
-                            tm['use_free_form'] = True
-                            tm['free_form_value'] = formula
+                            tm["use_free_form"] = True
+                            tm["free_form_value"] = formula
                             tm.pop("Tref", None)
                             tm.pop("C1", None)
                             tm.pop("C2", None)
                             tm.pop("TL", None)
                             tm.pop("TU", None)
                     if not found:
-                        tm = OrderedDict({'Property:': self.name, 'Index:': index, "prop_modifier": "thermal_modifier",
-                                          "use_free_form": True, "free_form_value": formula})
-                        self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].append(tm)
-                elif self.name ==self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname][
-                            'Property:'] and index ==self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname][
-                            'Index:']:
-                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname]['use_free_form'] = True
-                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname]['free_form_value'] = formula
-                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].pop("Tref", None)
-                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].pop("C1", None)
-                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].pop("C2", None)
-                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].pop("TL", None)
-                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].pop("TU", None)
+                        tm = OrderedDict(
+                            {
+                                "Property:": self.name,
+                                "Index:": index,
+                                "prop_modifier": "thermal_modifier",
+                                "use_free_form": True,
+                                "free_form_value": formula,
+                            }
+                        )
+                        self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][
+                            tmname
+                        ].append(tm)
+                elif (
+                    self.name
+                    == self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname][
+                        "Property:"
+                    ]
+                    and index
+                    == self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname][
+                        "Index:"
+                    ]
+                ):
+                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname][
+                        "use_free_form"
+                    ] = True
+                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname][
+                        "free_form_value"
+                    ] = formula
+                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].pop(
+                        "Tref", None
+                    )
+                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].pop(
+                        "C1", None
+                    )
+                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].pop(
+                        "C2", None
+                    )
+                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].pop(
+                        "TL", None
+                    )
+                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].pop(
+                        "TU", None
+                    )
 
                 else:
                     self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname] = [
-                        self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname]]
-                    tm = OrderedDict({'Property:': self.name, 'Index:': index, "prop_modifier": "thermal_modifier",
-                                      "use_free_form": True, "free_form_value": formula})
-                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].append(tm)
+                        self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname]
+                    ]
+                    tm = OrderedDict(
+                        {
+                            "Property:": self.name,
+                            "Index:": index,
+                            "prop_modifier": "thermal_modifier",
+                            "use_free_form": True,
+                            "free_form_value": formula,
+                        }
+                    )
+                    self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname].append(
+                        tm
+                    )
         return self._parent.update()
 
     def add_thermal_modifier_free_form(self, formula, index=0):
@@ -389,10 +496,11 @@ class MatProperty(object):
 
         formula = "pwl({}, Temp)".format(dataset_name)
         self._property_value[index].thermalmodifier = formula
-        self._add_thermal_modifier(formula,index)
+        self._add_thermal_modifier(formula, index)
 
-    def add_thermal_modifier_closed_form(self, tref=22, c1=0.0001, c2=1e-6, tl=-273.15, tu=1000, units="cel",
-                                         auto_calc=True, tml=1000, tmu=1000, index=0):
+    def add_thermal_modifier_closed_form(
+        self, tref=22, c1=0.0001, c2=1e-6, tl=-273.15, tu=1000, units="cel", auto_calc=True, tml=1000, tmu=1000, index=0
+    ):
         """Add a thermal modifier to a material property using a closed-form formula.
 
         Parameters
@@ -438,49 +546,80 @@ class MatProperty(object):
         >>> mat1.permittivity.add_thermal_modifier_closed_form(c1 = 1e-3)
         """
 
-        if index> len(self._property_value):
+        if index > len(self._property_value):
             self._messenger.add_error_message(
-                "Wrong index number. Index must be 0 for simple or nonlinear properties, <=2 for anisotropic materials, <=9 for Tensors")
+                "Wrong index number. Index must be 0 for simple or nonlinear properties,"
+                " <=2 for anisotropic materials, <=9 for Tensors"
+            )
             return False
         self._property_value[index].thermalmodifier = ClosedFormTM()
-        self._property_value[index].thermalmodifier.Tref = str(tref)+units
+        self._property_value[index].thermalmodifier.Tref = str(tref) + units
         self._property_value[index].thermalmodifier.C1 = str(c1)
         self._property_value[index].thermalmodifier.C2 = str(c2)
-        self._property_value[index].thermalmodifier.TL = str(tl)+units
-        self._property_value[index].thermalmodifier.TU = str(tu)+units
+        self._property_value[index].thermalmodifier.TL = str(tl) + units
+        self._property_value[index].thermalmodifier.TU = str(tu) + units
         self._property_value[index].thermalmodifier.autocalculation = auto_calc
         if not auto_calc:
             self._property_value[index].thermalmodifier.TML = tml
             self._property_value[index].thermalmodifier.TMU = tmu
         if auto_calc:
-            tm_new = OrderedDict({'Property:': self.name, 'Index:': index, "prop_modifier": "thermal_modifier",
-                              "use_free_form": False, "Tref": str(tref) + units,
-                              "C1": str(c1), "C2": str(c2), "TL": str(tl) + units, "TU": str(tu) + units,
-                              "auto_calculation": True})
+            tm_new = OrderedDict(
+                {
+                    "Property:": self.name,
+                    "Index:": index,
+                    "prop_modifier": "thermal_modifier",
+                    "use_free_form": False,
+                    "Tref": str(tref) + units,
+                    "C1": str(c1),
+                    "C2": str(c2),
+                    "TL": str(tl) + units,
+                    "TU": str(tu) + units,
+                    "auto_calculation": True,
+                }
+            )
         else:
-            tm_new = OrderedDict({'Property:': self.name, 'Index:': index, "prop_modifier": "thermal_modifier",
-                              "use_free_form": False, "Tref": str(tref) + units,
-                              "C1": str(c1), "C2": str(c2), "TL": str(tl) + units, "TU": str(tu) + units,
-                              "auto_calculation": False, "TML":str(tml), "TMU":str(tmu)})
+            tm_new = OrderedDict(
+                {
+                    "Property:": self.name,
+                    "Index:": index,
+                    "prop_modifier": "thermal_modifier",
+                    "use_free_form": False,
+                    "Tref": str(tref) + units,
+                    "C1": str(c1),
+                    "C2": str(c2),
+                    "TL": str(tl) + units,
+                    "TU": str(tu) + units,
+                    "auto_calculation": False,
+                    "TML": str(tml),
+                    "TMU": str(tmu),
+                }
+            )
         if "ModifierData" not in self._parent._props:
-            self._parent._props["ModifierData"] = OrderedDict({"ThermalModifierData": OrderedDict(
-                {"modifier_data": 'thermal_modifier_data',
-                 "all_thermal_modifiers": OrderedDict({"one_thermal_modifier": tm_new})})})
+            self._parent._props["ModifierData"] = OrderedDict(
+                {
+                    "ThermalModifierData": OrderedDict(
+                        {
+                            "modifier_data": "thermal_modifier_data",
+                            "all_thermal_modifiers": OrderedDict({"one_thermal_modifier": tm_new}),
+                        }
+                    )
+                }
+            )
         else:
             for tmname in self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"]:
                 tml = self._parent._props["ModifierData"]["ThermalModifierData"]["all_thermal_modifiers"][tmname]
-                if isinstance(tml,  list):
+                if isinstance(tml, list):
                     found = False
                     for tm in tml:
-                        if self.name == tm['Property:'] and index == tm['Index:']:
+                        if self.name == tm["Property:"] and index == tm["Index:"]:
                             found = True
-                            tm['use_free_form'] = False
+                            tm["use_free_form"] = False
                             tm.pop("free_form_value", None)
-                            tm['Tref'] = str(tref)+units
-                            tm['C1'] = str(c1)
-                            tm['C2'] = str(c2)
-                            tm['TL'] = str(tl)+units
-                            tm['TU'] = str(tu)+units
+                            tm["Tref"] = str(tref) + units
+                            tm["C1"] = str(c1)
+                            tm["C2"] = str(c2)
+                            tm["TL"] = str(tl) + units
+                            tm["TU"] = str(tu) + units
                             tm["auto_calculation"] = auto_calc
                             if auto_calc:
                                 tm["TML"] = tml
@@ -490,15 +629,15 @@ class MatProperty(object):
                                 tm.pop("TMU", None)
                     if not found:
                         tml.append(tm_new)
-                elif self.name == tml['Property:'] and index == tml['Index:']:
-                    tml['use_free_form'] = False
+                elif self.name == tml["Property:"] and index == tml["Index:"]:
+                    tml["use_free_form"] = False
                     tml.pop("free_form_value", None)
-                    tml['Tref'] = str(tref)+units
-                    tml['C1'] = str(c1)
-                    tml['C2'] = str(c1)
-                    tml['TL'] = str(tl)+units
-                    tml['TU'] = str(tl)+units
-                    tml['auto_calculation'] = auto_calc
+                    tml["Tref"] = str(tref) + units
+                    tml["C1"] = str(c1)
+                    tml["C2"] = str(c1)
+                    tml["TL"] = str(tl) + units
+                    tml["TU"] = str(tl) + units
+                    tml["auto_calculation"] = auto_calc
                     if not auto_calc:
                         tml["TML"] = str(tml)
                         tml["TMU"] = str(tmu)
@@ -510,6 +649,7 @@ class MatProperty(object):
                     tml.append(tm_new)
         return self._parent.update()
 
+
 class CommonMaterial(object):
     """Manages datasets with frequency-dependent materials.
 
@@ -604,14 +744,18 @@ class CommonMaterial(object):
             Whether to update the property in AEDT. The default is ``True``.
 
         """
-        if isinstance(provpavlue, list) and self.__dict__["_"+propname].type != "simple" and self.__dict__["_"+propname].type != "nonlinear":
-            i=1
+        if (
+            isinstance(provpavlue, list)
+            and self.__dict__["_" + propname].type != "simple"
+            and self.__dict__["_" + propname].type != "nonlinear"
+        ):
+            i = 1
             for val in provpavlue:
-                self._props[propname]["component"+str(i)] = str(val)
+                self._props[propname]["component" + str(i)] = str(val)
                 i += 1
             if update_aedt:
                 return self.update()
-        elif  isinstance(provpavlue, (str, float, int)):
+        elif isinstance(provpavlue, (str, float, int)):
             self._props[propname] = str(provpavlue)
             if update_aedt:
                 return self.update()
@@ -641,8 +785,8 @@ class Material(CommonMaterial, object):
         if "PhysicsTypes" in self._props:
             self.physics_type = self._props["PhysicsTypes"]["set"]
         else:
-            self.physics_type = ['Electromagnetic', 'Thermal', 'Structural']
-            self._props["PhysicsTypes"] = OrderedDict({"set": ['Electromagnetic', 'Thermal', 'Structural']})
+            self.physics_type = ["Electromagnetic", "Thermal", "Structural"]
+            self._props["PhysicsTypes"] = OrderedDict({"set": ["Electromagnetic", "Thermal", "Structural"]})
         if "AttachedData" in self._props:
             self._material_appearance = []
             self._material_appearance.append(self._props["AttachedData"]["MatAppearanceData"]["Red"])
@@ -650,9 +794,13 @@ class Material(CommonMaterial, object):
             self._material_appearance.append(self._props["AttachedData"]["MatAppearanceData"]["Blue"])
         else:
             self._material_appearance = [128, 128, 128]
-            self._props["AttachedData"] = OrderedDict({"MatAppearanceData":
-                                                       OrderedDict({'property_data': 'appearance_data',
-                                                                    'Red': 128, 'Green': 128, 'Blue': 128})})
+            self._props["AttachedData"] = OrderedDict(
+                {
+                    "MatAppearanceData": OrderedDict(
+                        {"property_data": "appearance_data", "Red": 128, "Green": 128, "Blue": 128}
+                    )
+                }
+            )
 
         for property in MatProperties.aedtname:
             if property in self._props:
@@ -673,8 +821,9 @@ class Material(CommonMaterial, object):
                                 mods = modifiers[mod]
                 self.__dict__["_" + property] = MatProperty(self, property, self._props[property], mods)
             else:
-                self.__dict__["_" + property] = MatProperty(self, property,
-                                                            MatProperties.get_defaultvalue(aedtname=property), None)
+                self.__dict__["_" + property] = MatProperty(
+                    self, property, MatProperties.get_defaultvalue(aedtname=property), None
+                )
         pass
 
     @property
@@ -701,21 +850,28 @@ class Material(CommonMaterial, object):
     @material_appearance.setter
     def material_appearance(self, rgb):
         if not isinstance(rgb, (list, tuple)):
-            raise TypeError('`material_apperance` must be a list or tuple')
+            raise TypeError("`material_apperance` must be a list or tuple")
         if len(rgb) != 3:
-            raise ValueError('`material_appearance` must be three items (RGB)')
+            raise ValueError("`material_appearance` must be three items (RGB)")
         value_int = []
         for rgb_item in rgb:
             rgb_int = int(rgb_item)
             if rgb_int < 0 or rgb_int > 255:
-                raise ValueError('RGB value must be between 0 and 255')
+                raise ValueError("RGB value must be between 0 and 255")
             value_int.append(rgb_int)
         self._material_appearance = value_int
-        self._props["AttachedData"] = OrderedDict({"MatAppearanceData":
-                                                   OrderedDict({'property_data': 'appearance_data',
-                                                                'Red': value_int[0],
-                                                                'Green': value_int[1],
-                                                                'Blue': value_int[2]})})
+        self._props["AttachedData"] = OrderedDict(
+            {
+                "MatAppearanceData": OrderedDict(
+                    {
+                        "property_data": "appearance_data",
+                        "Red": value_int[0],
+                        "Green": value_int[1],
+                        "Blue": value_int[2],
+                    }
+                )
+            }
+        )
 
     @property
     def permittivity(self):
@@ -769,7 +925,7 @@ class Material(CommonMaterial, object):
 
     @property
     def dielectric_loss_tangent(self):
-        """ Dielectric loss tangent.
+        """Dielectric loss tangent.
 
         Returns
         -------
@@ -817,8 +973,8 @@ class Material(CommonMaterial, object):
     def thermal_conductivity(self, value):
 
         self._thermal_conductivity.value = value
-        self.physics_type = ['Electromagnetic', 'Thermal', 'Structural']
-        self._props["PhysicsTypes"] = OrderedDict({"set": ['Electromagnetic', 'Thermal', 'Structural']})
+        self.physics_type = ["Electromagnetic", "Thermal", "Structural"]
+        self._props["PhysicsTypes"] = OrderedDict({"set": ["Electromagnetic", "Thermal", "Structural"]})
         self._update_props("thermal_conductivity", value)
 
     @property
@@ -889,8 +1045,8 @@ class Material(CommonMaterial, object):
     @youngs_modulus.setter
     def youngs_modulus(self, value):
         self._youngs_modulus.value = value
-        self.physics_type = ['Electromagnetic', 'Thermal', 'Structural']
-        self._props["PhysicsTypes"] = OrderedDict({"set": ['Electromagnetic', 'Thermal', 'Structural']})
+        self.physics_type = ["Electromagnetic", "Thermal", "Structural"]
+        self._props["PhysicsTypes"] = OrderedDict({"set": ["Electromagnetic", "Thermal", "Structural"]})
         self._update_props("youngs_modulus", value)
 
     @property
@@ -907,8 +1063,8 @@ class Material(CommonMaterial, object):
     @poissons_ratio.setter
     def poissons_ratio(self, value):
         self._poissons_ratio.value = value
-        self.physics_type = ['Electromagnetic', 'Thermal', 'Structural']
-        self._props["PhysicsTypes"] = OrderedDict({"set": ['Electromagnetic', 'Thermal', 'Structural']})
+        self.physics_type = ["Electromagnetic", "Thermal", "Structural"]
+        self._props["PhysicsTypes"] = OrderedDict({"set": ["Electromagnetic", "Thermal", "Structural"]})
         self._update_props("poissons_ratio", value)
 
     @property
@@ -1094,14 +1250,14 @@ class SurfaceMaterial(CommonMaterial, object):
     """
 
     def __init__(self, parent, name, props=None):
-        CommonMaterial.__init__(self,parent, name, props)
+        CommonMaterial.__init__(self, parent, name, props)
         self.surface_clarity_type = "Opaque"
         if "surface_clarity_type" in self._props:
             self.surface_clarity_type = self._props["surface_clarity_type"]["Choice"]
         if "PhysicsTypes" in self._props:
             self.physics_type = self._props["PhysicsTypes"]["set"]
         else:
-            self.physics_type = ['Thermal']
+            self.physics_type = ["Thermal"]
         for property in SurfMatProperties.aedtname:
             if property in self._props:
                 mods = None
@@ -1121,7 +1277,9 @@ class SurfaceMaterial(CommonMaterial, object):
                                 mods = modifiers[mod]
                 self.__dict__["_" + property] = MatProperty(self, property, self._props[property], mods)
             else:
-                self.__dict__["_" + property] = MatProperty(self, property, SurfMatProperties.get_defaultvalue(aedtname=property))
+                self.__dict__["_" + property] = MatProperty(
+                    self, property, SurfMatProperties.get_defaultvalue(aedtname=property)
+                )
         pass
 
     @property
@@ -1211,6 +1369,6 @@ class SurfaceMaterial(CommonMaterial, object):
     @aedt_exception_handler
     def _does_material_exists(self, szMat):
         a = self.odefinition_manager.DoesSurfaceMaterialExist(szMat)
-        if a!=0:
+        if a != 0:
             return True
         return False
