@@ -3,7 +3,6 @@ from __future__ import absolute_import
 
 from .application.Analysis2D import FieldAnalysis2D
 from .application.Analysis3D import FieldAnalysis3D
-from .desktop import exception_to_desktop
 from .generic.general_methods import aedt_exception_handler, generate_unique_name
 from collections import OrderedDict
 from .modules.Boundary import BoundaryObject
@@ -23,6 +22,7 @@ class QExtractor(FieldAnalysis3D, FieldAnalysis2D, object):
 
 
     """
+
     @property
     def odefinition_manager(self):
         """Definition manager."""
@@ -46,23 +46,51 @@ class QExtractor(FieldAnalysis3D, FieldAnalysis2D, object):
         design_file = os.path.join(self.working_directory, "design_data.json")
         return design_file
 
-    def __init__(self, Q3DType, projectname=None, designname=None, solution_type=None, setup_name=None,
-                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
+    def __init__(
+        self,
+        Q3DType,
+        projectname=None,
+        designname=None,
+        solution_type=None,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=False,
+        close_on_exit=False,
+        student_version=False,
+    ):
         if Q3DType == "Q3D Extractor":
-            FieldAnalysis3D.__init__(self, "Q3D Extractor", projectname, designname, solution_type, setup_name,
-                                     specified_version, NG, AlwaysNew, release_on_exit, student_version)
+            FieldAnalysis3D.__init__(
+                self,
+                "Q3D Extractor",
+                projectname,
+                designname,
+                solution_type,
+                setup_name,
+                specified_version,
+                non_graphical,
+                new_desktop_session,
+                close_on_exit,
+                student_version,
+            )
         else:
-            FieldAnalysis2D.__init__(self, "2D Extractor", projectname, designname, solution_type, setup_name,
-                                     specified_version, NG, AlwaysNew, release_on_exit, student_version)
+            FieldAnalysis2D.__init__(
+                self,
+                "2D Extractor",
+                projectname,
+                designname,
+                solution_type,
+                setup_name,
+                specified_version,
+                non_graphical,
+                new_desktop_session,
+                close_on_exit,
+                student_version,
+            )
 
     def __enter__(self):
         return self
 
-    def __exit__(self, ex_type, ex_value, ex_traceback):
-        """Push exit up to parent object Design."""
-        if ex_type:
-            exception_to_desktop(self, ex_value, ex_traceback)
-
 
 class Q3d(QExtractor, object):
     """Provides the Q3D application interface.
@@ -90,18 +118,21 @@ class Q3d(QExtractor, object):
         is used.
     specified_version: str, optional
         Version of AEDT to use. The default is ``None``, in which case
-        the active version or latest installed version is used. This parameter is ignored when Script is launched within AEDT.
+        the active version or latest installed version is used.
+        This parameter is ignored when Script is launched within AEDT.
     NG : bool, optional
         Whether to launch AEDT in the non-graphical mode. The default
-        is ``False``, in which case AEDT is launched in the graphical mode. This parameter is ignored when Script is launched within AEDT.
-    AlwaysNew : bool, optional
+        is ``False``, in which case AEDT is launched in the graphical mode.
+        This parameter is ignored when Script is launched within AEDT.
+    new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
         machine. The default is ``True``. This parameter is ignored when Script is launched within AEDT.
-    release_on_exit : bool, optional
+    close_on_exit : bool, optional
         Whether to release AEDT on exit. The default is ``False``.
     student_version : bool, optional
-        Whether to open the AEDT student version. The default is ``False``. This parameter is ignored when Script is launched within AEDT.
+        Whether to open the AEDT student version. The default is ``False``.
+        This parameter is ignored when Script is launched within AEDT.
 
     Examples
     --------
@@ -113,10 +144,31 @@ class Q3d(QExtractor, object):
 
     """
 
-    def __init__(self, projectname=None, designname=None, solution_type=None, setup_name=None,
-                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
-        QExtractor.__init__(self, "Q3D Extractor", projectname, designname, solution_type, setup_name,
-                            specified_version, NG, AlwaysNew, release_on_exit, student_version)
+    def __init__(
+        self,
+        projectname=None,
+        designname=None,
+        solution_type=None,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=False,
+        close_on_exit=False,
+        student_version=False,
+    ):
+        QExtractor.__init__(
+            self,
+            "Q3D Extractor",
+            projectname,
+            designname,
+            solution_type,
+            setup_name,
+            specified_version,
+            non_graphical,
+            new_desktop_session,
+            close_on_exit,
+            student_version,
+        )
 
     @aedt_exception_handler
     def auto_identify_nets(self):
@@ -160,10 +212,11 @@ class Q3d(QExtractor, object):
         if not source_name:
             source_name = generate_unique_name("Source")
         if not net_name:
-            net_name =object_name
+            net_name = object_name
         if a:
             props = OrderedDict(
-                {"Faces": [a], "ParentBndID": object_name, "TerminalType": "ConstantVoltage", "Net": net_name})
+                {"Faces": [a], "ParentBndID": object_name, "TerminalType": "ConstantVoltage", "Net": net_name}
+            )
             bound = BoundaryObject(self, source_name, props, "Source")
             if bound.create():
                 self.boundaries.append(bound)
@@ -200,8 +253,7 @@ class Q3d(QExtractor, object):
         props["TerminalType"] = "ConstantVoltage"
         if netname:
             props["Net"] = netname
-        props = OrderedDict(
-            {"Objects": sheetname, "TerminalType": "ConstantVoltage", "Net": netname})
+        props = OrderedDict({"Objects": sheetname, "TerminalType": "ConstantVoltage", "Net": netname})
         bound = BoundaryObject(self, sourcename, props, "Source")
         if bound.create():
             self.boundaries.append(bound)
@@ -240,7 +292,8 @@ class Q3d(QExtractor, object):
             net_name = object_name
         if a:
             props = OrderedDict(
-                {"Faces": [a], "ParentBndID": object_name, "TerminalType": "ConstantVoltage", "Net": net_name})
+                {"Faces": [a], "ParentBndID": object_name, "TerminalType": "ConstantVoltage", "Net": net_name}
+            )
             bound = BoundaryObject(self, sink_name, props, "Sink")
             if bound.create():
                 self.boundaries.append(bound)
@@ -278,8 +331,7 @@ class Q3d(QExtractor, object):
         if netname:
             props["Net"] = netname
 
-        props = OrderedDict(
-            {"Objects": sheetname, "TerminalType": "ConstantVoltage", "Net": netname})
+        props = OrderedDict({"Objects": sheetname, "TerminalType": "ConstantVoltage", "Net": netname})
         bound = BoundaryObject(self, sinkname, props, "Sink")
         if bound.create():
             self.boundaries.append(bound)
@@ -323,14 +375,15 @@ class Q3d(QExtractor, object):
                 for sw in setupdata.sweeps:
                     if sweepname == sw.name:
                         self._messenger.add_warning_message(
-                            "Sweep {} is already present. Rename and retry.".format(sweepname))
+                            "Sweep {} is already present. Rename and retry.".format(sweepname)
+                        )
                         return False
                 sweepdata = setupdata.add_sweep(sweepname, "Discrete")
                 sweepdata.props["RangeStart"] = str(freqstart) + "GHz"
                 if not freqstop:
                     freqstop = freqstart
                 if not freqstep:
-                    freqstep = (freqstop-freqstart)/11
+                    freqstep = (freqstop - freqstart) / 11
                     if freqstep == 0:
                         freqstep = freqstart
                 sweepdata.props["RangeEnd"] = str(freqstop) + "GHz"
@@ -344,7 +397,9 @@ class Q3d(QExtractor, object):
         return False
 
     @aedt_exception_handler
-    def create_discrete_sweep(self, setupname, freqstart, freqstop=None, freqstep=None, units="GHz", sweepname=None, savefields=False):
+    def create_discrete_sweep(
+        self, setupname, freqstart, freqstop=None, freqstep=None, units="GHz", sweepname=None, savefields=False
+    ):
         """Create a discrete sweep with a single frequency value.
 
         Parameters
@@ -383,18 +438,19 @@ class Q3d(QExtractor, object):
                 for sw in setupdata.sweeps:
                     if sweepname == sw.name:
                         self._messenger.add_warning_message(
-                            "Sweep {} already present. Please rename and retry".format(sweepname))
+                            "Sweep {} already present. Please rename and retry".format(sweepname)
+                        )
                         return False
                 sweepdata = setupdata.add_sweep(sweepname, "Discrete")
-                sweepdata.props["RangeStart"] = str(freqstart)+"GHz"
+                sweepdata.props["RangeStart"] = str(freqstart) + "GHz"
                 if not freqstop:
                     freqstop = freqstart
                 if not freqstep:
                     freqstep = (freqstop - freqstart) / 11
                     if freqstep == 0:
                         freqstep = freqstart
-                sweepdata.props["RangeEnd"] = str(freqstop)+"GHz"
-                sweepdata.props["RangeStep"] = str(freqstep)+"GHz"
+                sweepdata.props["RangeEnd"] = str(freqstop) + "GHz"
+                sweepdata.props["RangeStep"] = str(freqstep) + "GHz"
                 sweepdata.props["SaveFields"] = savefields
                 sweepdata.props["SaveRadFields"] = False
                 sweepdata.props["Type"] = "Discrete"
@@ -430,15 +486,17 @@ class Q2d(QExtractor, object):
         nothing is used.
     specified_version: str, optional
         Version of AEDT to use. The default is ``None``, in which case
-        the active version or latest installed version is used. This parameter is ignored when Script is launched within AEDT.
+        the active version or latest installed version is used.
+        This parameter is ignored when Script is launched within AEDT.
     NG : bool, optional
         Whether to launch AEDT in the non-graphical mode. The default
-        is ``False``, in which case AEDT is launched in the graphical mode. This parameter is ignored when Script is launched within AEDT.
-    AlwaysNew : bool, optional
+        is ``False``, in which case AEDT is launched in the graphical mode.
+        This parameter is ignored when Script is launched within AEDT.
+    new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
         machine. The default is ``True``. This parameter is ignored when Script is launched within AEDT.
-    release_on_exit : bool, optional
+    close_on_exit : bool, optional
         Whether to release AEDT on exit. The default is ``False``.
     student_version : bool, optional
         Whether to open the AEDT student version. This parameter is ignored when Script is launched within AEDT.
@@ -463,12 +521,34 @@ class Q2d(QExtractor, object):
     >>> app = Q2d("myfile.aedt")
 
     """
-    @property   # for legacy purposes
+
+    @property  # for legacy purposes
     def dim(self):
         """Dimension."""
         return self.modeler.dimension
 
-    def __init__(self, projectname=None, designname=None, solution_type=None, setup_name=None,
-                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
-        QExtractor.__init__(self, "2D Extractor", projectname, designname, solution_type, setup_name,
-                            specified_version, NG, AlwaysNew, release_on_exit, student_version)
+    def __init__(
+        self,
+        projectname=None,
+        designname=None,
+        solution_type=None,
+        setup_name=None,
+        specified_version=None,
+        non_graphical=False,
+        new_desktop_session=False,
+        close_on_exit=False,
+        student_version=False,
+    ):
+        QExtractor.__init__(
+            self,
+            "2D Extractor",
+            projectname,
+            designname,
+            solution_type,
+            setup_name,
+            specified_version,
+            non_graphical,
+            new_desktop_session,
+            close_on_exit,
+            student_version,
+        )
